(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    198262,       3912]
NotebookOptionsPosition[    195396,       3817]
NotebookOutlinePosition[    195904,       3836]
CellTagsIndexPosition[    195861,       3833]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Effect of Phase Noise on Squeezed State", "Title",
 CellChangeTimes->{{3.4554612358110437`*^9, 3.455461248382044*^9}, {
  3.455467025486044*^9, 3.455467028364044*^9}, {3.455470101803244*^9, 
  3.455470102864044*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TextStyle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
     RowBox[{"FontSize", "\[Rule]", "13"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotopt", "=", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0.7", ",", "0.2"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.5", ",", "0.5", ",", "0.2"}], "]"}]}], "}"}]}], "}"}]}]}],
   ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Using Takeno's 2007 Optics Express Paper", "Subsubtitle",
 CellChangeTimes->{{3.455469733846044*^9, 3.455469755717244*^9}}],

Cell[CellGroupData[{

Cell["\<\
Assume 70mW Pump, 140mW threshold value, escape efficiency set to 0.947 = 
next gen value, current OPO is 0.925\
\>", "Subsection",
 CellChangeTimes->{{3.455467114985044*^9, 3.455467147105044*^9}, 
   3.4554697268416443`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Lin", "[", "x_", "]"}], ":=", 
  SuperscriptBox["10", 
   FractionBox["x", "10"]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dB", "[", "x_", "]"}], ":=", 
   RowBox[{"10", "*", 
    RowBox[{"Log", "[", 
     RowBox[{"10", ",", "x"}], "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"thresh", " ", "=", " ", "140"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Threshold", " ", "power"}], ",", " ", 
    RowBox[{"in", " ", "mW"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"op", " ", "=", " ", "70"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Operating", " ", "power"}], ",", " ", 
    RowBox[{"in", " ", "mW"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Eta]esc", " ", "=", " ", "0.947"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Escape", " ", "efficiency", " ", "of", " ", "new", " ", "BT", " ", 
     "cavity"}], ",", " ", 
    RowBox[{"calculated", " ", "0.947"}], ",", " ", 
    RowBox[{"current", " ", "BT", " ", "has", " ", "0.924"}]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sqzcav", " ", ":=", 
   RowBox[{"1", "-", 
    RowBox[{"\[Eta]prop", "*", "\[Eta]esc", 
     FractionBox[
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"op", "/", "thresh"}]]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SqrtBox[
          RowBox[{"op", "/", "thresh"}]]}], ")"}], "2"]]}]}]}], "  ", 
  RowBox[{"(*", 
   RowBox[{"Squeezing", " ", "without", " ", "phase", " ", "fluctuations"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ASqzcav", " ", ":=", " ", 
   RowBox[{"1", "+", 
    RowBox[{"\[Eta]prop", "*", "\[Eta]esc", 
     FractionBox[
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"op", "/", "thresh"}]]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox[
          RowBox[{"op", "/", "thresh"}]]}], ")"}], "2"]]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Anti", "-", 
    RowBox[{
    "Squeezing", " ", "without", " ", "phase", " ", "fluctuations"}]}], 
   "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sqzfluc", " ", ":=", " ", 
   RowBox[{
    RowBox[{"Sqzcav", "*", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "*", 
        FractionBox["\[Pi]", "180"]}], "]"}], "2"]}], "+", 
    RowBox[{"ASqzcav", "*", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "*", 
        FractionBox["\[Pi]", "180"]}], "]"}], "2"]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Observed", " ", "squeezing", " ", "with", " ", "phase", " ", 
    "fluctuations"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ASqzfluc", " ", ":=", " ", 
   RowBox[{
    RowBox[{"ASqzcav", "*", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "*", 
        FractionBox["\[Pi]", "180"]}], "]"}], "2"]}], "+", 
    RowBox[{"Sqzcav", "*", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "*", 
        FractionBox["\[Pi]", "180"]}], "]"}], "2"]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Observfed", " ", "Anti"}], "-", 
    RowBox[{"Squeezing", " ", "with", " ", "phase", " ", "fluctuations"}]}], 
   "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"dB", "[", "Sqzfluc", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Theta]", ",", "0", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Eta]prop", ",", "0.5", ",", "1"}], "}"}], ",", 
    RowBox[{"Contours", "\[Rule]", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "10"}], "]"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<RMS Fluctuation angle, \[Theta] (\[Degree])\>\"", ",", " ", 
       "\"\<Propogation Efficiency, \[Eta]prop\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", 
    RowBox[{"ContourShading", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"11", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"10", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"9", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"8", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"7", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"6", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"5", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"4", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"3", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"2", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"1", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"0", "/", "11"}]}], "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"Style", "[", 
      RowBox[{
      "\"\<Expected squeezing level, white region is 0dB, darkest region \
between 10 and 11dB, 1dB contours\>\"", ",", "Medium", ",", "Bold"}], 
      "]"}]}]}], "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"dB", "[", 
     RowBox[{"(", 
      RowBox[{"Sqzfluc", "/.", 
       RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}]}], ")"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Squeezing level as a function of \[Theta], for given propogation \
efficiency of 75%\>\"", ",", "Medium", ",", "Bold"}], "]"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<RMS fluctuation angle, \[Theta] (\[Degree])\>\"", ",", 
      "\"\<Squeezing relative to SNL\>\""}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "5.1", "}"}], ",", 
      RowBox[{"{", "3", "}"}]}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4554612516010437`*^9, 3.455461307621044*^9}, {
   3.455461376109044*^9, 3.455461385106044*^9}, {3.455461418521044*^9, 
   3.455461456326044*^9}, {3.455461583504044*^9, 3.455461736221044*^9}, {
   3.455462135826044*^9, 3.455462138474044*^9}, {3.455462181886044*^9, 
   3.455462251408044*^9}, {3.455462337787044*^9, 3.455462358054044*^9}, {
   3.4554623963440437`*^9, 3.455462401548044*^9}, {3.4554624492960443`*^9, 
   3.455462484740044*^9}, {3.455462556280044*^9, 3.455462566698044*^9}, {
   3.455463313743044*^9, 3.455463367074044*^9}, {3.455463413914044*^9, 
   3.455463481039044*^9}, {3.455463618396044*^9, 3.4554636704100437`*^9}, {
   3.455463759519044*^9, 3.455463864114044*^9}, {3.455463898248044*^9, 
   3.4554639001340437`*^9}, {3.455463947505044*^9, 3.455463947539044*^9}, {
   3.455463987772044*^9, 3.455463996906044*^9}, {3.4554668429500437`*^9, 
   3.455466895026044*^9}, {3.455466942595044*^9, 3.455466985898044*^9}, {
   3.455467029647044*^9, 3.455467089972044*^9}, {3.455467150007044*^9, 
   3.455467223427044*^9}, {3.4554672567450438`*^9, 3.4554673857960443`*^9}, {
   3.455467428320044*^9, 3.455467453697044*^9}, {3.455467883136644*^9, 
   3.455468003023644*^9}, {3.455468091208844*^9, 3.455468287735244*^9}, {
   3.455468329034844*^9, 3.455468365367244*^9}, {3.4554683954596443`*^9, 
   3.455468493646044*^9}, {3.455468527638444*^9, 3.4554685289020443`*^9}, {
   3.455468564345244*^9, 3.455468657898444*^9}, {3.455468698442844*^9, 
   3.455468773759644*^9}, {3.4554688111478443`*^9, 3.455469007349044*^9}, {
   3.455469130527644*^9, 3.455469147172844*^9}, {3.455469274468844*^9, 
   3.4554693638100443`*^9}, {3.4554694020144444`*^9, 
   3.4554694983444443`*^9}, {3.455469552180044*^9, 3.455469639168844*^9}, {
   3.455469767604444*^9, 3.455470077529644*^9}, {3.4554704310694437`*^9, 
   3.455470630234644*^9}, {3.4554706817302437`*^9, 3.455470683368244*^9}, {
   3.455470725332244*^9, 3.455470740791844*^9}, {3.4554710482660437`*^9, 
   3.455471122958844*^9}, {3.455471296096244*^9, 3.455471319870644*^9}, {
   3.4556402131927156`*^9, 3.455640278416316*^9}, {3.455640568435916*^9, 
   3.455640572148716*^9}, {3.4556407008175163`*^9, 3.4556407250443163`*^9}, {
   3.455640770221916*^9, 3.455640873852716*^9}, {3.455640910231916*^9, 
   3.4556412789067163`*^9}, {3.4556413441927156`*^9, 3.455641426108316*^9}, 
   3.455641473797516*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1fQVY1M/z/4GAoCjdHTbYhTVrYrfY2N1+vsrZ2GIrih0oiopgY2Bgi60o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   "], {{
     {RGBColor[1, 1, 1], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtVUtvjVEUPfe77fnOvcLtw6OqGoSOiLSCRIiJiZiIkTCQGGhEokNSUzRe
fXmlJISkQrzjUfWIgX8gITHwKBERMVGq9aq1stZg5+yzv33O2Xvttfc3f3vH
pt1ZCOEJpAhZh81EIYQt0IdgeABZif2MFMIw9OlY38FnNmQc9psxhEboP2F/
i7UBMgZ7N9Y78E/Qb0T5j8HnepTPD+jXoM+C/h36Zuh74Buhv8lsx34O1vWQ
nUGxDDseSidkMSQl6Vtwx4GqEPZD9mJ/K+r8eNJ9KyBLgvzoX5OHcBX6TNhH
k/Jg/sz9kXNfB79yKYS/WE/C925RebVif6+oPfX2aul8d1FUfLtw/1piA30D
7jyMuAawbyvINmb7PtjqIc+Dcp7lOBkTY6uJ8iVuq4Pwok9tVK3GXa9VxLUg
n514exT7aqwtWPdAnsFeQYz3HTNzY41HYF9jnXHXJ/nUYc1LirUHb03BHZ8h
Zb/z3W8R19GCYq5JwqU2yfbN9k/wmQeJkD5Ib6bcmNMq50UMd1QL31c4fwh4
5Yj/A743Qf7hrstRWNWVhPch13p5QXVv83rA+sEq4U69y3b6cz1oO9/kGXJ1
EPdXiG1JtRqDHIdUsM+xnsf3qlx3vUSMp7CfxLkp+H4iiifkS69rk6AfjcIr
Qu+OwpO4jmTi3K+C3mC9lkE/HIVdNXxeJMVZzMXJI1Xi5bmoeBjXGehF6FOh
vzauxH0I9gXQJ5P6hP1FjrEXyUty73YUthPwuQO9GfrvpD6kf56UA3Ppw/d7
UXX8mxQf4zwC2+MonhVgewh9IYdKSbgQn9OwhVxc35rEgaWQZph7MvGSnPyY
KYYMUsLZ38QGZy+YfzWwpVxnn8LWkcl+F/e8z9TvfwrCgpicdX4bIXvhUzaO
c/G9P+p+vkNOfSWvIP2Z+ERufMmUyzTznngOBs0y4ljvWr025syjx7mRQ+TS
pah5R67XRfXrbONPHIlnY1TcczzrOLOozzB33ngeTsvFy0oubo6an8xjxFzq
dK1Zc2K5GdIVxLu3ns/spSZjwtq+8zzvNwcrQX3BnmS/1Bsb8oe8++Re5nuN
npn83uI5Qx5Qb47CbqFrxJp8dH0/G8+yuUKfuZ6x7Z4D/N5uzNk/xOKYe/SL
6/LTs3t6VB+zduxl3tfhd9kzQ57n7NH35gl7g280mV9l+5Nn3F90f3/w/Fnj
fw+xXW/cWa/o+XYqqEeH/f+oOEZi0u9aEd/MPGdd2G/UG6K40+2+YC47jD+x
oM68cmM/aDwzv8seZk1nmte/HBvzZtyc84xxm/15J99qNV/2ub78XrRPnXvj
StQ/pOJcWJPcMZDrfZ47X80BcmHA+bKP6NPjvJabZ+QYz/S6d9iT7M2GJFuf
/bt9lnGyj1k/8pbrH+uT5jTxPO4e5rvk/qTt/wGWfgaD
         "]], PolygonBox[CompressedData["
1:eJwlk1uIzVEUxvc5Z6z/H3HOzJkZx2BCLo+Sorx4mZQ3KcyQpoaaNDKPI56R
M+7XUEQRuceQS3n04klMUe5pEh40MUkuv6/v4avv22vtvdde69uzevpXbS2m
lJaDBlDOUjrJQh0xHv44UlqAbgVX4JUwfw1WE3+GXgafCq7DS6ztYu9O8DxP
6SlrS4nVwLXwmTpbOS+ID4Pd8G2FlLqIv0IPoh+WUppAbgb2oO+gy7lzlKu1
l+g68XLJNebwCthOfAmYG96jvUOgAm8K1/IWrCX3CXoxfAq4Cm8M8zdgDfEx
dD98DngA/wsG4PPAI3gzZ94vuWbVfoK1f9zdSXwEPghGC75Dd23kzC/wMriA
3oT+Bq+CS+hJ6EXkj6I3w7eAn0XPZDK8E7yD/yLnIPnjMucqR7ld4D38N/HD
xNejPxZd03H0OvQH9B/0UfQG9Cd0CZwK90S9GSO+P9wD9eIHei+6iTfeLbnn
6n0vWFjwWpVYX+beqyct6B70Z/ZPBOdUD2s74APqEXoYdKDbwI2wp+Qt9ayO
7kaPoDNwRv4AK+DTwE14New99US92ReuVZ6T9xpzz141qtbvrPUSmw3uwU+H
394NvsLPhu9SjnLPh2uXB+SFi+HZyQPywvTwWXqj3toSrk09Vq9blVP0DDSL
Grq96J6r91nuXsizOfxYeDYrdQb8SHiWerPefiA8G/05/b1a7r/Swdr8sOfk
Pd1xO/wmvW0mGAqfqbNV0y14WzimHqvX7WFvy5Py5oyw9+VZefdQ2HuamWan
P66/rj/cQLw5PEt5UF68HPa2Zp7Q/wE0kIyj
         "]]}]}, 
     {RGBColor[0.9545454545454546, 
       NCache[
        Rational[10, 11], 0.9090909090909091], 0.9545454545454546], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmWuMlsUVx5/33feZ5+G23BbEcllXQWxVUm1FWJB+MhHTxKa6LOtCETBi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         "]], PolygonBox[CompressedData["
1:eJwllUloV1cUxu/75/+/7yVRM6pRE5OIcQJBpWit4NpFV4JYqqh1IQ7QLoQu
unCAGqc4JraaNo7VKm2dtSMU3QoiiFGhVm0dkarRaJxi+/v6LQ6c757vnHvf
mV7j/E+mf5wLIXyG5JHK4hBGFFCSEA7GECqQu8CLGLuzEH4FT0F/D2kBl4Nv
Y78AfiqM/zD8X3G2B1tZGsJaLliJ9EMfAWcytk+LQhiJ/hOcSfhORNaC94KH
JY6hWNvA/cEDwCXgCXCu4TuDs3Ho65F38e1D/H1wh0a//RVnCfwD4CbwcPwr
wK3gKnA1uLjYPvKdAP9zYi3kjU/AM5E72DI4lXAfEHZz9Bv1Vt35M/gN/B28
px3pRd+C/QLcqdi3opfiX4N/F2dfwF+lHBF7F/zmzG/S23qx78fehX4mOMcb
sD8nZivcNqQHfShnZ9Gn8Q216GX4N+DTg89O/J9zdhXfMuyHwQ+xHQ/O8Tps
Kfxyzu5zthF7AzG/5z2l2OdiLyD7iH8dexn2Avw+Bdd4HbgTfRp6B/ybcGs4
6wbfA78GB/g9edfwF2zjkPPEW4rcSF0T1UY1+Q3bl8igxDlSrr4C1+rbwH3B
bZlzWc0bW9HnY38feytn18CXkYPgQ8S/gj44OhcPsfdmjqFYemM7tkvI9sTf
3Ji6p9XbpTqL7gn1xj/wt4JXZ75bOVmjXkN2wp2JTNS3wR0T/I1N2Gqje7+b
mP+C66Jrq5woN52cdRBvBZLn/shZv4JnrAXuLqQ+cU1V2xT+t8Q+gETVD5/V
Oce4Cv4munfVg+rFQupZ244sSu0j3wKcD6JrpFop5yfAHaox3AXIY/SbqWul
GQ3gF/Cv5z0zR8Gzsd+Cm+gOcDX2FvRnSH/lKjp3f+DTA94RzZ2DPNAsI4+C
Yyr2BnDfxDlQLlRT1fb/nHI2h/vu5PzGr+F+BL6HPh7ObvBL+H/lvSOOgUdH
z8ZypB7bpuhZUM+r9/WN+tZG5HT0jGvW65Dj0W/UW+uRk+i/qyfwXwPONN/a
iYl3gnZDLvMsa+ZLo2dCs6EeU69VgLtyrlk5+jzkzyL30GLsb1PvDs28Zl85
U+50xxHsszLXbhQ4wK1Rzoi1GW5dsUW6alCCfVD025Uz5a4qendpJ2g3aIdq
l6oGbdE5VC61Y7RrDkXfpX+A/gWbMu967ayN6MMz51YzOBbuktS1b0eatMuj
Z0MzORnukOhcq2bz4JZkntUBqg+2Z+DOvHvgh+gdpF2kHT8evTJ6V4kjrv4x
+teoJt9hK099d8rZh7oLac55h2uXr4+ebe0w7bKi1LOnf9IlYr1IvVu1I7Ur
KzPXWjWrQh8Y3RvqefW+/jn696iG72TeMdo12lmn4J4jxrLEO7oOW0P0t+pN
zal3gnaDZvxH2aL/Deph9fLfqf+N2rFJ9Dfp27QDMuz/AS4d648=
         "]]}]}, 
     {RGBColor[0.9090909090909092, 
       NCache[
        Rational[9, 11], 0.8181818181818182], 0.9090909090909092], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFl1uMVlcVx/d85zv7bMCmEtPgTKUFkU4bb6htqSm2tcSZMA9QmxRiY1pa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         "]], PolygonBox[CompressedData["
1:eJwllWtolmUYx+/32fvez23z+EFkWx6mmQQec2iRRyQFPzgT8tSHzFTIPBQe
gpS+6Ka5nFNLFBQKxIn0JRFJxEAUQZ2kgik4llOaVOoy1CSc+vvz//Dnvc7X
/Vynt3rx6jmrshDC56AInuYhSNAN/Af9O/isLIRx6F6UQrgDNkF3IpuaQpgP
bhRCWA1qYwhrQG8CzUR/Gt+30N+G7o5sOboJYGHBNkvQFUAfco2Fr4e+gr4R
fTOySvxHwrfgfwEMQV8FfoGegU0F9EjwPu/5Ctko6HbsD6E7jv9w/N9D9hzd
MOJ/Cb0hmdab9fae3UIYwDc9JsZ+fLug9+B7EJ9e8G+AM/oW8Cr2K+F74X8H
/m34n8jRQaxV+FUQ611ku4jVhH469CjsL5W5hm3YvomsFXoeNmP0NmTrydcD
dEGPj47dDsajv0/cH7A9Rc5O+Hno15NvNPwm+D/w2YDtRtAB/b9k6PphcxTb
u/A/Fl0T1eZKyb38Dlkbuh1gAvRQ8n8DXYPNtTLHVOzXkf0K3YD/ZXwz+O/L
3DP17qPcs/KUmIugdyKbrFoje4R9G1gS/Aa95WD0t/4FNsOfjM6tGmyH/zr6
2z4lx03ijUW2LLhmNdCD0JdDP8J+OfrzxN9Y8ExUoo/I6jLb1EMPSO5dOTH6
Q88GXfCf4DMLelL0LG8DnblrrFq3oH+C7mcwJPNObEueQc3iRTAiuufqvXoy
F/5x7t6rZwn+z9yzqRpk8E2av8w12gU9ETQXvBPvoF8MthQ885r97sSvJP6/
+O+Fv4l9o/oLfwH5h8jqsK8Hfcn1DP3f6Cvhj0X3TL1bS7wQ/Y361gbwD/Sl
kmM14dOK775oX+VU7nXIBhdds9rkndZu6wboFryC7Aj8Zt0M6Ibk3qpmJ4g1
O/o2aEcWJNdctddOzoEuJe9aX+yL0NXRs/uMnBn5K3Lfgh3IlkbvhHZDN2Uc
fBX6w+gngaslQ/QX6Avapdx0Lf63oa/jv7XoHdYuHwD9C74BugW/8Tstc0zF
HpR7VyWrzv2N+lbFuJE845p17UQ5sT5Ovj3q6Qr4I+AB/BTsd6N7LXl2EvwH
6BYl30bNuGZdM6/ZXwFaodtz924W8W5BTwYtmXui3miHtcu6mbqdd3PfAt3E
ayXXVLWtwWYr9LfJb9EMahZVY9VaO6Pd6Rc9a7ohuiXaAe2Cck5B/zD37OjG
dRC/Gf29zDekEfuK6FuqGdQsVkXfhofwz3UvomdVN1G3cVl0b3VzdHtkI1v1
5Hh0z9Q73aBh6EZH10I7MhS+Lvm/Q2/QW3QTdBs0kwOja6xa64YPxPZs9H+H
dki7pJnX7GuHzmn3kmulnql3LwFfTupk
         "]]}]}, 
     {RGBColor[0.8636363636363636, 
       NCache[
        Rational[8, 11], 0.7272727272727273], 0.8636363636363636], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV1uIVVUY3uecvdbeIxRWjqD2Yo4TmBfIGZrRMS0ds8TRGc0aSMJbWHQh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         "]], PolygonBox[CompressedData["
1:eJwllEtslVUUhc/9773/f2yigQBKcaCVh4a2mhgIllsemhQIBNveFggmKC3F
CAEMjxEkGGBASMDHRKoSnmJMGAADEhjYTmgFtKIDE1uwTYwBpZRXdKAQ4Fus
wU72Omvv89h7nV3V/mF5QxJCWIcVsE1pCMtzIZwBDMcQ/s1C+CwfQhtr/+BP
he8F92Avwv8MrmeDb7AO/Grse7idxK/Af56Y78Ckhgn4Jex4zmfUaS+IMvxJ
+JvFEH7ERgefURW9Ju4+eDH4AbgPfJ773QNPJf8MZz8NbgO3R/s6Q2d1wnfj
f0De+KdCOMxaE/wJcl6Au4ud1V2xO/h93KkEdxwbD75MXh3+Rs5/hH+dtf3E
lrFrehT7Hcj7ThXkrgWPK/hMnf0LObPI/xp7DvwX1go3QM5rxLaRsxicEZfn
fqfhS3C17LEbbhn2MrgAfof4MvwV9rqKteLXw9+Ev4HVwzdj3dzlAbiM/zf7
fgo+R/4IeC85o8Cj4Pfh/wG/A3wLPDe6pqrtbe6UwM9Kze3GRjJr4IkWwPOI
XZi6N59j/8G9Au7Ou+eV0Wfq7C5ybsP9qf6D2zmzn7Pvq57EdoHvgN9PXdsK
/AL1eDW6Vqr5r6zVgn8Dt4Cr8evI70lc8zXgJdF7qSdLo3uu3ncQ36DeEt9L
/GrsRtEal9ZVA9VCb9bbVeMW/AHWFuB/xH4J+auIf4b4zcRXw19gbQb8UexZ
cBM4D5/DlhG7EjyF2CO6Y+YaqVZ68/+ZNSFtSGPSmvbQXm9gl1L/Kf2tZvY7
yn6rwMcSa/Qn/HdZqyi4JjX421mrKvhP6W91srYAfIj4sZk1JC1JY0uJfSn6
ry7CalL3SL1STWdm/gP6C/rjl3V29F3eAh+SVlh7PXHP1fvN2MmcNdkRrUlp
cxgrwf2Q+m16g96iHqvXDdRoNXgPdjdnze+KnjGaNZopmi0TM2vnbfIn4Vdm
ztUfm4D/kL3mF/xmvf33zG/T2n7wJ5m1rxnzceY/pr+mni2Hn5daK6rhluge
q9eN7F+DP1i0fwqbDN5GTFLwn9sqvcOvT6wxaa0/tValeWl/DmungmPm6n9F
10aaWkdsU/TfVUyj/m9m7WlmaHZIs9KuZnIkfijzbNIMGcx8J91NmpV2x4AP
Ju7RpaI1KW3qzo2pZ6BmoTQkLWkGaRZJs9LuF6xNg18E/xX+e6m1PF1vlP6w
w4n/wMXUGpPWlNMD/jI6VzGKnZ161kojb8L1Fb2X7qi7SlPSlmb0Efyh1L3W
jP8WfCvzLNJMK8I1RM8izfBr7PUYhFLYPg==
         "]]}]}, 
     {RGBColor[0.8181818181818181, 
       NCache[
        Rational[7, 11], 0.6363636363636364], 0.8181818181818181], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1l1lsV1UQxi/9/++CDyYaJDy4ABojS6EtJooGBNewqriABrAoCUIrRWNE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         "]], PolygonBox[CompressedData["
1:eJwtlGloz3Ecx7/7H7/fbx4owgNHDGkXOaZYEXO1ZZaJ0JYjtTna3LMHrlDE
KMu5zZgHjkTyxFEUxphzW7bFzLVhRSKlEV7vPnvw7vd5fz/H9/v7XHFLC7ML
Qs65PBABkz3nFsc4txpyK3DuGliJfBOjMb5zV+E5ITu7jjwVfA+bTxryV2x2
w3PgX5BnctYJz4OnE/urZ7FncnYb/Sz4QOS/xNwAP419FvoS7KuQ74EieC36
iejro3x551HOWtHd4SwT/7voxyFXc7YqZD73kd9gX4j9ZfhneP9Y53Zwtof4
T7i7Hp/F+D/C5hDya86q0J3Hvh376fA+6H+BdHgbOBMxmxZ07+FV8EX4NxH3
mWdvT0HuzV1L0X/Edw36Jci1nt09En0v9DXw0ei2w/vBc+Bx8EJ4X3gT/HiM
3aG72uAX4FfgHfBG7LKwr4S/gztQwX0F2Pzz7Uw6xWhULPhO5AzOypA3gWER
q4FqcRKe7awGp5BvgOshq3kH+gPE7KlcEGOvb2/W2xXzAfpWsADf+eAMvom+
/bvOzqoe6BciXyLeUHS7QCzxXmLTHd2rqOVSOVaudYfu6oFNCfI+3+R4cET9
gM8kYp0DJ5Qf/HND1oNRz3KsXCvHD+ETPOvNi2AS9hnwfORakBlYT6m3ZsPz
0MXDnxOrHoyGjwJ1YTuTTj2sXlYPqhfHom9GbgRJ6FPhn5DbQSr8WGC5H8x7
qtF95m3LeO8tkIL/eFDp7CwV+Q/6zchNIAueDV45O5vjW4+oVzJ4b65nNrIt
Bj+i1tPqbeX4sG8zpFkaxBvW8ZYWeAG6GpCM/xDfajMDNEdt5jX7vbDPDyym
YqvHunn2Zr1dOW/r6nn1fhp3PkX/Fnmrsx4agW0R+BeymatDHuBb7Up5f4Ny
53XdHbZcamdod7wApdjODWxRNcK/Ra3H1es6m4cuH/vYiNUoAb4CJIQtp8sD
q4FqoZkc79nO0e7RmzYil4OksO2sg9JFrVbK0RF8awLbNdoxP/F/hH5bjM3E
fux/+/Y29VQn8uDAcquZ1mwXBfYvmrniwGqgWujOMt9yrFxrp04JbAdpF2mH
tXDX8MB6SzOaHNhO0m7SP04j/hbPelk7az26tZ71unpQvZgYWC9rh2qXPvas
VtqJ2o3lgfW+ZqoisBnWLGtmNbuJnvWa/jlO8wzKIraDGqK2Y7VrtaM+eLaj
tKvUA+oF1Vi1lo98/wOH1OCc
         "]]}]}, 
     {RGBColor[0.7727272727272727, 
       NCache[
        Rational[6, 11], 0.5454545454545454], 0.7727272727272727], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVk1oXVUQvi/3vnMPgm7cVVyICVYRQcXSjWLUBmzfi21Si5BaQdEmkhcX
9rUpmCJKXRQjWFM3aRIhIhjzEiXR2tQgVK2SLtQmoUVbE00rmkJojW4U0e/L
94mLw5k7Z+ac+flm5t705HMtXXVJkvyFlWKNxyR5IkuSMeyNOBjB6iskSRn7
JNZwQd/3F5OkGfIb8yR5CvzPci3SJ7HPQ2Ye9Bz2XsiuS0VvAq+GtQu6JewT
WF2g2/Hmx6Db/E6r36JOFfQoZLZg/wBrCLxb8EYneAu4uwm8Max+8CewDoDf
i7Wayp4B0FPw51m+gb0CnX9Ad0J2Gqs5lUwLZI/R54LsoD09iWw5Xqd7KXuq
IPlfcM9R7Btgy1bwH0ll50ydvknvxVmFPmA/BPmr4L9q2WbLNPub934J+/bC
ti+w12ey8xPI7MTqhszjiexjzHrMYy7IvxAU00vQnQXvdcjdBvpikA+/gn4e
qwbZ+3LF4fZUuToblJufcL4fqwHv7sPejvUa5O/OFZud4G/Dngf5zhiMRvHf
w34+KE/rIX/OuVkC/3vz3wF9GWeP4c13o+4iXUmEkRtS+ftGLvph6E06r8zp
lVTfpPeDLmXCIWPQaEyST5qxYc6oy1hVnYtm3DkQpXsU+x6/8XTU/ddn+h7E
dxn0bBCOpp135qea6Zt3lG3DSeN/BfJzqewoJ7KFNGWY+6lMsetzPbAWGHfS
Z4vyhWfM6ee0D/K/B73Hd0edd2KC95eMj7ZEOKI8sbQxKLaM92RRdjP3d4G/
Ffz1UVghZs7j/HBBfN7HWiq5Nrsz6fL9VuwtWJvrdCdrmzZ9i3texP5NVN20
uHZYw62uHeKW+WauB3JhbxD7PdBZAL0B+0RRddKRqU80OT6sv+2+pzNTLdcK
6h9l20ld8olXYn/O8SfuacMizu/Idc+PoP8O6i1fR/UU+sQ4sm/RF55tcb9h
r6EdtUx5GctEV0yPZ5JhvMfM5/mY+TOZfGL+WXvMw6kofm8qPN+bq3f0BOWP
OFnrXdhPGDPXQLYDa6UgTHXbR9o64z455XcGjIuScXIG91+E3r5c9cw4HY/q
nSX3T9oyY33au2affaH/9Is9qd79c8g47XSdtTnvjOWOgt5vNKa7XbvTdZJd
DsrlCdgwV9S8WQT9UdQ8OIb9jyD8fRU1izZ5HrHnMh6XobcUhLcaZJYKsus0
zn7L5c9qrvMR9wFinPhgTJaj8HAJd/Tl0j8YhKMOY6w+FZ937g7SXYBetag+
WXE/HnEfoz7lx3HfnqJiTt0Gx439jXNtnXvdvOcc6QeiZsRDUXOBNcecDrpe
toN/XRAODuaqP9Yh8TRu+18Jkr05092s3UnX6UuQyXH2suug5nnJmNE22jnt
OTzhfjNnG+hH1b5wJwa/A304ly9Hsa8auy8E3U3sHHBNVf0/8KBnCmcL5/lm
11jNtUI8fYiz3bQ7Cm/zjg/7xFsFYYt2UqbN2K24Rlk/rIUzvr/V/Yp+M5en
XUcr9odzbZvx0eWeyd45bLx0uW9fdU19GvVv0RgUk4ZU9/R6thOXa7Gvk93U
W7Uuexv7FP2n/BXX/qL/t+bC/32Tcbs1qi+3O6ec2czVtUGx/7MoHeremGte
cm6WomzK7S+xSizWu1exL9FPYrJqPmPK2HKOsIfzP5B183ZUz0+DZgbr586g
+qA/9Jk4IRb/w3WvMVlyvZXdN2j/vPvCDr/FXkwsLvsfbcL9//1c+Xo0KIaH
HLc3c8X8SK7eP+z6Y4+c8uzjjGddduPOn6PkfgDvQlE0eUd8z2wuzLGvED+5
88n4tkbFuwzdfvdt/kPxn4az6ZxjT13O9yZjcZfrhTGvGJv9tpN10eG+yj7C
fsL/NWK0xXlgPqi71nOi/kmeifp/4kzifxZtHnIsKVv1W/8CC8eZYQ==
         "]], PolygonBox[CompressedData["
1:eJwllEtIVVEUhrfX4z6boCbNekEPK6OCjKJJkL0GdS31WgQFQVFmmRbotaCB
9JoVZNEkjQY1yLpaZKmZNFGLJpUaSmYGGoSBVLdGEfT9rMHi/Gv9a6+91+ss
PFRTVp1wzpUiETKe51wV3zaUb8G5U965LhxSyCR4LTKU69y1HOcqwB34HMN3
P/wTcG/s3G74EqQPXI5tJbgK/xT4HdKA/wf8d8DPR4rAu7hzHrgbvgo+g/9p
4l/EVgfOJ8ZN8Fv4uoTFeA/+y3sr4WYgs/DfgywBx8h5/AdjOztJjAFwA/wL
7pqL7Tr6VmL8BF/FtgVcA9+ZsJyeBctBubzBthH8GtsZuB7i1eO7HNvOhNVs
GbgQ6UFvh6+F/8T7kuityCK4L3lWy3akAH0V0gEuQybwn0Lfy9ky7rjLXU1I
EnxWOcDleuNSyD24S7HlrhqpVqqhalkMfzuYj3wfE38p3DTnD4OznHkJdxl9
Isdq9gi+FdvByGqgWqgH6kU5+mr4B/AHInuz3j7o7S69sRmu2FuvFfMG/IXY
evGRN82EGyX/O3Dj2NYpP/g54Az8LfAw/DZityAL0Otj691JJA0eIcZ2uAxS
6a0H6oVy2gDfSczjkc3QlLeaqXaaWc1uJlitlWMb+Ku33DTjmvU+bOnIevwH
/bPy02wjJ8At8KUJq8FDzUKwt+WrR+Aib7XVTG0OdkZnNQNj3nqu3ivmGLlm
0a/g20T+sbeclJtqMOytBqqFdmQI/+955tvNfdPE/41PbWQ7p91rx1YR2Qxq
FpPBZl01boxtR7Wr8nkKPsf5/hyL0YveFWwXVMPn4P5gvVFNXgX7J+jfsI8z
1ZxdEexfUIIUoqfRF0e2883cNxBsd7Sz/+A3IT9yLedf8EfhZ0dmE3ck2O7I
VgFe4y12I1KAXh+s1tph7bJqoFooh6y3GdesaydHve2cdk8zM0Lt7gd7u3qo
XuofpH+R3qy3rw82m9pB7eJ/6civDw==
         "]]}]}, 
     {RGBColor[0.7272727272727273, 
       NCache[
        Rational[5, 11], 0.45454545454545453`], 0.7272727272727273], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlktoXVUUhs+959yztwMHceAsLVJQEQUVFCNotaNSqQO1xhpy2wasNoU0
gSioBZtUjC8cObHiQLCDmKSmqSZgqrTm1fpsnYh2YNGCVamCdar1//xXyOCw
11177bXX4//Xvtf17XtooFkUxXf6Sn1bk2QpRnNR/FoXxeOSb5NurFUUL+ub
aBTFHq3/VkWxW/Jp7e/VN6Gz3aX1yPck65e0TstuQmeel3639p+o7Ke3st/X
CuvGwv82yY/qe1dyl3y29H0umzrk7wvbcmb17McNyx8o7rZ+T2kdlu5Sw/a7
mrZ5W/Kizi60HNOKdMcbjrmvaRmbmZZjfV3yp/K1T/InWk82LeNvMnw8J5sD
iuuRyvJh2e2lnrVzQc/vqZZ/k9cfsumXj9+l26CzPzWcI/f3Rz2J4ZXIE789
2ntW6/amZXRz2pvV19bvkeQa/aD12quK4n7JtWI4IfudkT+9oA+v6uvQucGW
82Ufe/wsR8zkNCP9eMMx35D8+0atQy2fxceTyuUa+qr1jdJ13NFw7B3RG2pO
vfCD78moG+tU6KkNMvubSsezGjcr/aW34BDs0Av6QPyTurtHuvez4+oLPT2c
iRqCZfInd2JDT3/p4XTUEww/Vhrbw7X3b1e+P0veL/mW5PiWo6fUazZwOFpa
xv/1yfuHIx7qRU1uTd7/Rb/Xy3ahuYbBpcAeua1Uvm8xePS37j9YWs891KAd
PAIPOytjAt7QI+qJfU/42SI/81rPgOXa545Ivqk0n8kXv72RC3lybiK7loMR
P/zeE7xBXgnuTASnwBbreOAMXDNPzmt9MGYLM+Zits2PYbsQGPhNeyOK487s
s+eDF9TgVNw1nZ1vpTxGtL5Qee//uVX5TG9pPTnPZPeeeXaudl/oT7u0HfbU
7mjwCywPBXbBDVgBgx9l4+mY1l2VY6D2HWEDVqajH2DpbHYM32idza45taee
n8WsAS9zgRlqsBh1mAx5dUYthD3+iJl8wSV3fijfi9mzeH9tDtD38Wx+nAgO
MVdOx2wBO72Bjfmm8yFuMHgyuEMflmMOHIvc57T+ST20v1n3Z+09VXrOvli7
Z5PSb66Nqa9kv077N1fuIzXfUfr8VMwE+MRd3NMv/VvJuDyU3A/01PO+2hjc
na1jD/sDMfeYf3PJc4P5d3Xt+A5Kty7mBfltyY6NGOF6d8TTWTpW4oRn8If6
DGafH9L6ZrLN1to8IM7V/nRW9o9ufbWmXwp+XyjtE14sR85gcTY4De9OBXaJ
J0ddh0PXDj3vxV3lGj/YA+f/BB++VZyp9iy+nPyG3l3aD+9nV8j0pCvyHajN
Q3gJ9uEAtX4m2zfz41D05YHg7oXIhZxGQ95YeyYOyfZe2V2SfqPWI8kxTyXP
rrGY4fC1HRzEBzzAD+eOBi/PJmPmTDJWt8ccJ8aOeKPh93zowTp6MHxHNkbO
6b6HJV/hnSau2tw4zjzM7t1Adn2G4z/D5dqc4a2+GP+FmCXTyfV8qTZ26Bl9
uRL46YyPnKjdaLLPbbJ/OupDnZgB/cFrbDujF7x17fg/81dyH8A+93Af/P0i
Gbtfan0vG0vMzpXgNbWE95viDWVWd8e79nX2WXyQ74a49514I+j5Urw7vD//
Af9BXgY=
         "]], PolygonBox[CompressedData["
1:eJwlk02IzVEYxs+9/3v//7OxsZ+RLEgKixlDIUqJWDAjmbpjplyayVwjrEZj
7mAhWdlYsJKa5lsYGeSzKF9jIx+lmKJmJmVsKI3f41m89Tznec55z3nf9yxu
q+zqzIcQthAF4lMawh5AE3EthnCAWAg+j3YMbWUWwgQb9hHf4X3wmKDlQqiC
PxAp/D3+38UQpuF98CmiAf8Ua2N4Z+EbOLsHvZh4zylwgqeDvb3wq+gjrK0F
r+AOZ9DesDaB3gOfBPcTzQXnUK55PFX4O+63Ez6A3h3sGQR/Jn8/+a+jL0W/
Ef22MvpNcIH9+8GtxBi8Hs8jvG16L3vXwB+DF6EfRX8NLyXOqdwniIfotfAj
6PeISsFr0mbwN+ecYxTtLtGat+e+zot+Wy/xF38d/gd5e2bhw+gD7C+hj4Bf
oO8l/x3e8IP7DUVrevNX/HPoF9Bb2PMTPEh8ATewNgyuj651O/468En2PEPv
IN969EbW5tFriCvwanRtdcZp9YO1lsQ1UC22Zr6L1iYz11C11MxodlRD1VJ3
ylL3VL2thV/MPHOaPc3Ax9Q5lVs9vwzuRK8puAfqxUt4OecavAKvzjyb5/Cv
Apej364ZPhjdM/VuOf5L6IfhT3M+swKe5n7tefdcvf8/s4lnphO8MXp21UP1
cihzLZcQjehNqf/COvgo2tnUWDOsWR6PnjX18Bb4V+paPyeewFP4Jrybidv4
Z1gbx1/CfxytKzOWZzxzTuXWH9Jf2pG6lurZbvZ+K7oWOkNnbY9+u2q2Dbws
81/Qn9ff7059F9VgDvyH/YcS//EFqe+ku2kmNZtvo2dVM6PZ6YqefdVUtf0H
ubKVsQ==
         "]]}]}, 
     {RGBColor[0.6818181818181819, 
       NCache[
        Rational[4, 11], 0.36363636363636365`], 0.6818181818181819], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVEtIVVEUvb533z3XcYMsm+SwBtXAmhWkhBU0iCZNNcioLH0WRqRWL0h0
0CxtFtVA+6hNUvqoRX7KysdzUA2EIKiBEQQVWlBrtZY0OJx9993ftfbZ6+tP
7G/KRFF0HSeL8zqNovY4il7hflYWRcch90Nfibs7F0UPoWvAGYTcB/2pJIpG
8b0I+x7ommLZULcqKxvqGOca5GXYtyDhTCodYzL+mqzytuJfHroKfBcRoxZ3
DU4jfRyHdfFQx/jTuI9kFGckKE/CPLCd8r9f+M7jHsP/LOJtw8mXqS/mY65l
52Bs1jjtmJdgOw19gX7wH2BPqP85/CZx7pepR/bP+haDfHa4xxn3nnXOt5Dr
Y8XsgrwxVj0zkL8ixkHIs4ixBPkw5PeQO4N8O3BXQbcV5wP5QY518G9OhQe5
ISbEftn4PEvVy1lgcDIVP6ch/8Fpg/5NEAb9OfUWZ1Ur6zwK+wnYtyXihDyN
Qv8kVc+PcJ9JZENbzgVr6IVNA/4P59Qra2R84s3YVe6X3BBv4ky/CfvSZygn
mX55+z4I6qsZ970g3O4E8UA+Bs3JkHnhPWy52zGYaw9qXYLvXuPGGWswvsT5
AHpaXS59OeQviTisxv+WVDhxFjhftZ7PUkZ4luD/ORG3m2BTA/knbI6Zq0q/
kaFUc8J5+YF7LfRXI9U86N5Zc4/fXV1Os8T+iQlj/avDfBHPiVRz/zQVtlPG
d9zf38xj3lyTo0Ox8GGN37PKy/6Jw92g/N2e7Qnb9XonFFe4i8UZe+Y7oUyb
Jc8McxYcnz3OZfTG6M+55Hy+RI27gv7NQu6Avgj5VtDbpS1nbzhVnti757n5
3Qy7R7DbEpTnh3OR/wb3WOV3Q6w2QDef8XcsfMkx+170O+VeY45P+HcR+RYg
30D8fUFc8w0x/6jfHd80OWV9o0HzwzlqD3pX73DXpaptZ6J9V3JfrKPk2piD
uS4k4rDRPPZ5/3AGt+Nchvwxpz4W7F9w35fd+5DfIP8tOBd3DOeV+Ykx8aW+
6N3X717qvfe4r6lfSsRnq+0LifbXBfzvTIXp+VQ5Jz3Hg36bxId7h7P8OBVH
Bc9Sm3fIFfT3ItUMcBbGg+rrMPZF5632nh/xrmUc9ss+5jwr7JccEU/OBTni
DPBNdnmO3pjHuSCfiux/LubNzc0geTfu20G7dyDo3TAuY455Rn+jznPmmpyf
8Jvnnl5e4ZA4B+Ffh7s20e5pCZ4H5/0LW1IdBQ==
         "]], PolygonBox[CompressedData["
1:eJwlkz1I1lEUxs/r//X+r7MQKS412mIQuUiCCr0VNuTUqkEI8ZqvBSYqagq2
teZsg1YiLuInvjmUH4VSQzoITRUYguBnDf4ezvDAc+5zvu45915p7XiQLzGz
GyAL3qdmtYnZNYzhYNaJfY5DOWf1sqNZFdpCxuwp/JCzdvTPYBV7EFSj/0Sf
IPY6WER7xNkffG+jH5HrBDRij6Ffhk9S+w38V6nZXMZjarC3QDf8G9iGD4J9
9C4wAF+K3kue/MvwTbCFbxf4F7ymareBGbQn0WsXiXmBFtQDtXPUvVRm9gW9
H98KfHJo9dgj8FF8bik/NR9iPyP/BrwOfIIXiCmi51LvVT4HpT4zzU53eh68
hmppprP4NoM18zveh79Ovbc20IT/PXKeJT4jzUo1VVs9fkW7g/29xGc+EP2O
uusrcv4mfhf9ceIz0+x0J91NOe/i+zF679rhCnwj+i4L4BzffPTdaOcd8Lfk
2EbbI99L9AZwnPhOtduz4LHawTp2D3Zl1n1y2EPBY9XzOLl6QYKWBX3wndT5
D2qeMqdC6rNo1AzhZcF5E5iXb/C7akfT5P8ffPfqcQV9EtxEuwpagr9JvU2d
vUv9TJp6UC/KqdzaqXb7IfW3pj8xpbcc/a3pzfwldij6X9EOtcsL5M51bA==

         "]]}]}, 
     {RGBColor[0.6363636363636364, 
       NCache[
        Rational[3, 11], 0.2727272727272727], 0.6363636363636364], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFUz1PVFEQvbvv7b3P3qCWW1oJRjoawcgarfwqoNsEY4JR2LVhWVDhD+gv
MBp1V/0BfkWDaKKyLiQ0akH8AXZU6lp4jucYipeZN/fM3DNn5lbr185eLYcQ
LuPL8J2uhNDLQxgguFkKYQ62g/jTFMIoAI9hl4sQDgNzA/YD/reAuwM7j9h5
YLrAL8QQDuH/CjB9nE0jvgR/A98i4r+isO+R+wz4LjDH8N9Jup88WKeaKf4d
uBPI2Q//NjAXMuUzt5SJW6Ok84E5vwHuJP5fJ/XRqCi+A9wsvufwryf5d5Pq
sS77Jt+pTGc998X4GnA1+H+i6kzC34ZdyuWzZhOYGcRewfbL4sD7eV4zfigX
5lEQL57z/wFyRoBZQf1N60b92NsPfF+CtBhG/CP8M1Ec2UfVOjG+jXpHMnE8
bh7jsOVMerFODbNYx3kLNdYKzW8dtpWrd87maKa7yPkA4gdzaUj+5D1jDXas
J++lT3zJM+Fd56L8J+DQrahWx7OrupcJYOqsV4jvnHeQe0Q8z0bNn/hh98u7
Lnp23Ady2rK2Lfe8mJRP3oz/329yIB/2wjPWHHF9alN3He47e+N9zOVOMP9+
ks73YAdRe/C5EJcFY9q5NKWetNx/akWNW/bfIacJfzeKKzl/9U7yLr6Ftvfg
n5YV8SZ/zq3p+i+S+DVg3xbKG4O/GjXLh/BfJsX3ka9rsjZ1Z7/jUXp3rclP
2EvI/Zb0/jmDW8B+StJ9wzznzeFmIf1OJc+nvLc/Q57jZNSc+FaYM+XZUbO+
Z8PYtOPcO75t9jvrM+r2O0rfHu6cSMLugm+7EI7vY8z9su+/Q4Gnww==
         "]], PolygonBox[CompressedData["
1:eJwlkskuhFEQhevvbv//20uwtLQyhAcwRBM7CRs7CRti3Gi08QV4AvMQHgAx
DwvdpqQ3WIgHsLMxLnwntTjJqapTt26deyt6hjoGE2ZWBVKgMTTrCcwuQWts
1kFckTQLQCYyS4MCDZWIp6n3g1J4Ocig/QOtaNPgDO0JaIHf09MAv0Q/gnaH
WRfwGfSFwHvOqd+Sm6J+TW6S2iK5Empl5MaJ24hv6K0htwGfD51Xg3XiLfBG
bx3xDnwVVCX9zrr7C+gjfkczDd+OXKsdtesd87PMOmBGC7VnkKD2RPxZZLZL
PEpvPbm9yM/QWcpl4cWh79aOtrTYbJNcbdJ31K5HxL3wYe5zDM8yr5t6P7mp
2D2Td7rDL/oV4tfAd1iDf5AbS7mH5+iXI++VRtqZ2N9GHsgLeSbv9EZ6K3kq
b3XGFXEeTRdn73PnJvhA7G+pP9CEdi72XeX5bOwey2vttBD6DtpFb3wqb8Bv
wt+sOfQ/o78jDyfgjZH/hQwzvqh/FPlsefAQuefyfpJ6nnlLxI+Be5YOvUe9
nbpT5BDXDjn4d+i9EyAX+xvoLXSnw8hzqumP/aD9By3zZVA=
         "]]}]}, 
     {RGBColor[0.5909090909090909, 
       NCache[
        Rational[2, 11], 0.18181818181818182`], 0.5909090909090909], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFkztPVVEQhTfncM++CTRWNjZ2NNrYXcD4IhTSgIUNlQmNCQ87MD5+gz0J
aIHUGGiEi1DwMHihEAKXXyClDdcEE9eXWcRiZ/aes2ZmzZo5t19Mj00VKaXn
OqXOUVdKZzprurdySuNy/q6l1OxO6YfOrvwdBdwpA7sizIDux7LPZG/qrAqz
Jey2zo7ul4qfkP80R45+vf8qR1PvIfnXc9Q86I66m8ZQ86oI/0t9f1eP+sPC
t4rgdi7/ot53dV+QnciB7ZEd0TkR7qnsqyL4kn9S77buN2T3/K1TCVdFLDnI
23EMueEN50YteuM+Ldwf2RnZX8INCjcjO0dO2bEqeuAb/nlh75fxLuuB762i
1q0ytFq1nuiKftTiTdygY+/ZosWXHH7yoeVILTRbt7ZfZYermMuHHNo2rD89
0/sj+V+b81z+X4P3hjAPdF/LwYVY+LSL6OfCc6Mu2i7liH1fDx8c8JMDrejx
wlqQnzlvWk/wB575vufCfB573t9lD4uYKfuy7FpL7uubtaJOx7WeOGYohwbk
Zj/Re8v7ieUNB+bMvK/3nNmA+eQdY9fgDO56P9kZcraMP7ImcOQbvODHDjTc
LzzZDzT4bI5njkX/pv+10SriZoV5mEPLjRz/36H384207hP+bT1yN12L/4Qc
H3PoTV7q9bnfc/Nrm//PHHGj3ouW8/8DueqfkQ==
         "]], PolygonBox[CompressedData["
1:eJwlkjsvg3EUh0/7ak8TXVgsFiYLixVxjaFdsJokFkMvYRDX+Ah2ibCw0y5S
EQMhwYJQ38CEREJC4vk5wy95zv1/zvt2zZWnS2kz60YtaDNn1p+YXcIbcN7N
nlNmjyQV4VFUhevER+Bd1Ef+L74luBUtpKJGtRX0TWyYnEbWbAv1wl/4SsQ+
Mmaz2LfYY9jXHqwZV/Ai+oE7yJmktu7R64L5n5nooV6aUYbfePMZi1SYf++R
o9xzfO/E2vHtkNtEU/ADGkiiRrXrqAd+of7GQ+L/N3rsqF07sYvZ6Kne6lEj
NoHu0rGjdj2RL4kdtMsTmsd+pecqXPC4rWrGPXqqt96wlosc5VbRCtzwuL16
nsJtqJmKmxeoPcYeSmJH7brtcbsZfVN42eM2g9hHcD4brBrV7nl8e33TffjA
Y7b+iUP4DxggTiw=
         "]]}]}, 
     {RGBColor[0.5454545454545454, 
       NCache[
        Rational[1, 11], 0.09090909090909091], 0.5454545454545454], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVL1Om0EQPGP7u5MwlkhBDRRgY/PzBiFSUpEiUJMCE1pImcpSlAYeACh4
BDAuCOlimxBken7S0IcOU0RpM+MZKcXq9u7b252Z3fumGjtr2yMhhA+wPGyx
EMIGnN+5EOaKIXRhV0H+FmwZ59sxhAesn7MQvsPqSPARZ8e49wr3q9gfwjqI
r2D9im/3yFFC7NuobyWsPeyX4B8k5XjpuqzZcd1NnH1BzkecdxA/j7gxxPfw
vQabw34wotqsW8Z6AqvRT4p/F5WnAbtDzr84O4L9hF9Bjtmi7l5j7bt2Ky/O
xFBCnjb2+0mxvEteo0l1p6mB8VAf4ukbG7mR4wVizqJE/hRVt1oUTuIiP3Jf
tVYvoow+9SO+Wet5k6RJLgoLz8mFuKktMV9Y28tMvLrGU7L+o1ibxrxk3arW
gXgmrdWOe82eD/U2x+ekfv3B/sn9JrbTvOaE+g3xGhv1GDiGmJ/sbzlny/Ur
xjBImsM71J3JVHMiiWPfOlAv6lbL6ezaHImzbl7M++CYsbwwMObeM/EL63kU
l2fPVdeY2POsIE7UZKEgXRb8RiadmzWoedcYOuZaNccN3yFeYmsaZ8X9pz6s
v+gY4mwaPzUpe555t1f8/y57zlO3FuT4w1pRs/dJ+NeT6jf8vrhueuZ2o/Lv
Rb3dst/RbRTugWefGjA/15Z9vq22ffaR31ibM0E+35BjJVO/xz1v5EbM/HdQ
uzeeL3JgntdRWq5E6Rs8h4+uN+yj3zXf9z+SnIr3
         "]], PolygonBox[CompressedData["
1:eJwlkDEvw1EUxe+/r32v0pKIhElCGSv1DUrCVANmBoSNGrsb1AdoOpjMhISw
aYT0E9BafAAbU61+N2c4ybn3nHfvfWd+v7l9kjOzWZAHg2S2F8xqFPfwc7AK
v6ZXKppNUl/y4A8cwy/ARJDHvZtgCe07M2tHswUwjr5M7wXeYcZdkKdHPTVm
Vi2YreB/pW7wvs8dXfQN+A7+mNebMnyd3lcmzxr8EPzkdFMj6ma/vY7/Ef4W
tdt3+K5PegdoA96P6G2hzwX9+QOtBSyo59pT0qwqM56py2CI5Ype4J7TJM1v
asJn6N0G3bwLr0Rl94vnKCkTz+YM/R19kfomKMM2+nRRWfgMn5Ulef3mYdJO
3+03PiTN9NmesWddSsrOM/Fs/gFtMzX6
         "]]}]}, 
     {RGBColor[0.5, 0, 0.5], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFUrtOw0AQ3HPM3SHSIUENoQkNICGXkWwSakQNDUKUUEd2asIH8B9AmQIh
+IQgUH6EmhnNIorRnfcxOzvnnau789vCzI6BHhDWzApgGsxGQAUcAM9IPvUU
b4AONTXOcWk2w/0E500yGyK2G83uce+j/gHnKXIL3FvkltlshYHzqB7ykJ/f
jJ8l8bL206SFmlqfW3ucfY1re0fvEXo318HpmpcmvdR9GDSLceojH3Pk6Wft
dJG1R+e7NKV6p843ck7mZ7478y/OX/kM6qGWNvz7wzjn/qDvGvXfSfX0Z/jX
C+wDk1L9tfPQu9ZrK68hJ+tYQ8+6QhreovgGUT3ckzvSF3J9IL6RxcX3mSfx
7SF+mfVG21ngfSvLp+D/A99i4Z7Qg7FrYKzwNxq4Bv4L9Gbl2r6SdAacr1H+
PoL/F58ZPb8=
         "]], 
        PolygonBox[{{2140, 377, 954, 2141}, {2061, 945, 1090, 1726}, {2007, 
         868, 636, 2006}, {1570, 297, 780, 2059}, {1872, 729, 946, 2062}, {
         2197, 1090, 377, 2060}, {1731, 561, 1093, 1729}, {1729, 1093, 1092, 
         2198}, {2062, 946, 945, 2061}, {1793, 636, 729, 2259}, {2198, 1092, 
         297, 1728}, {2070, 954, 1094, 1574}, {1929, 780, 298, 1928}, {1574, 
         1094, 561, 1730}}]}]}}, {{}, 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1526, 2007, 2006, 1793, 2259, 1672, 1872, 2062, 2061, 1726, 
         2197, 2060, 2140, 2141, 2071, 2070, 1574, 1730, 2323, 1731, 1729, 
         2198, 1728, 1571, 1894, 1570, 2059, 1927, 1929, 1928, 1572}]},
       "10"],
      Annotation[#, 10, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1873, 1810, 1972, 1548, 2051, 1971, 1912, 1617, 2004, 2288, 
         2005, 1970, 1973, 2289, 1525, 1974, 1725, 1904, 1903, 1902, 1665, 
         1861, 1860, 1867, 1868, 1804, 1803, 1893, 1611, 1809, 1901}]},
       "9"],
      Annotation[#, 9, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1527, 2008, 1915, 1914, 1913, 1618, 1959, 1960, 1958, 2175, 
         2174, 1863, 1953, 1954, 1952, 1951, 1908, 1612, 2172, 2173, 1997, 
         1998, 1522, 1859, 1994, 1993, 1992, 1784, 1858, 1857, 1981, 1982, 
         1980, 1979, 1907, 1607, 1937, 1991}]},
       "8"],
      Annotation[#, 8, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1528, 2009, 1918, 1917, 1916, 1619, 1962, 1963, 1961, 2177, 
         2176, 1865, 1956, 1666, 1955, 1667, 1957, 1663, 1984, 1788, 1983, 
         1787, 2252, 1862, 2250, 1785, 2249, 1786, 2251, 1659, 2243, 1778, 
         2240, 2242, 2241, 1852, 1978, 1545, 2327, 1977, 1906, 1604, 1936, 
         1656, 2155, 1657, 2156, 1603, 2119, 1602, 2120, 1658}]},
       "7"],
      Annotation[#, 7, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1508, 2110, 2111, 2028, 2224, 1540, 2225, 1839, 1768, 2226, 
         1769, 1841, 1840, 1511, 2284, 1653, 1599, 1905, 1975, 2326, 1542, 
         1976, 1845, 1773, 2236, 2238, 2237, 1654, 2160, 2161, 2157, 2159, 
         2158, 1847, 2162, 1945, 1946, 2123, 2122, 1608, 2253, 2254, 1995, 
         1996, 1519, 1864, 2001, 2000, 1999, 1791, 1870, 1869, 2178, 1668, 
         1964, 1966, 1965, 1620, 1919, 1920, 1921, 2010, 1529}]},
       "6"],
      Annotation[#, 6, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzb1KgnEYhvFHwnTpIFrMxSVQWoLm0MXsBIJq0yWaakn0CFprKkHzI8jq
BGo2Ww0aWiShIZsCoV/DxXXf9/O+/Ff3auVqIiKKmCQj8umIAj5TEVe8tBxx
zRl9IrfkN87qa3j3z9RWtW1gZmvrHXRxg5ztw60nD9BHTX/gR9zhHkOs+/bI
bV8+xAG29G/7HCl56s2CPOMv97ntBE/yz7/dnrGJU/3VvuARj/GCbbdjvuBL
VOQdlHx3rjd4wE2+5V0+4zpW5F9v/wE3HzBo
         "]]},
       "5"],
      Annotation[#, 5, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzsvQwEYh/HX4DL5BDRhUoOELiaJyyIRQ2eTpUTiEqFsBr4AYWn5HNQg
IdSsTdpBaWklOthMFr8zPHn6/N9zktOR1a3sZk9ErOCvN2KwL+KkP+IYFzhH
BS/IYx97WPbcwUDEIfI40mf2RV7Sp34XUcCunuEnLuMRv557Tt7labcH3ONH
39lneY4XMI81ZNxvuIRrdD1zyzs84dby/V3d0dto41s37Wn3Bn/pN/sGGujo
V/uoe50/dd2+jho+dM2ecq9yU1ftw3oIV7qiL7mIti2jc3hPbt4Z5yk9xpOc
Tv4P/wOq4jn1
         "]]},
       "4"],
      Annotation[#, 4, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzkvhFEYhuFDMrYaESTWitFRGJFoSEhEYquQWBoKkonaH7CVMyhsBX+E
2GmnECIUwiBUluD6ijv3+zznPV/OVzMx1z+bE0JIYjA/hH4MIBfvBSH8xELo
M39wUZ4l3Z88zEN403/LX/hEj51e/bP+UF6Q5+Uu7uZOLisMIe1sRp5GqzmB
V2dZ+dHdZvmBY7oXcxbt5g7nd/onTsqJiOgb3MYTGEeD/X2+0e/xLdfr6pBx
/16X0bWg0dyEOMZQZWeLt7GJXexgyu4VSrz/MvoPe+dcKV/wJE5RLJ9wqfMj
rpCPeQzrvrOBNRxEu3bS5l9vSvG1HNfXmke43N3R6I2ojv6La/jM/ordVSxi
GUtI4R9kXT02
         "]]},
       "3"],
      Annotation[#, 3, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0Dsvg3EYhvHHuWYRaU0GiYToYmudBkaHDorFoZiEQSyMBvFxfASJSEhE
OlhoXhGhSKQkWPm9w5Xrue/n+ad527e+W9ppiogKLtsicpmIXmQx0B5xjnvz
lV1XR8Q11+QL/Qq6davc0hmxxnkkugf8ub1Bj7nKiXdV+5ycxaa51bstHsGz
7gV13Lofdp/Hq/yGZjd3+n5zwnW7R92QPIiKvC2PcoGLXOQN3uMzN0/eTcpj
ckP+xFf6u/op/TS+5R9k3LzrC+YPbtj96ibkcezLs5jDDEqYxwEOsZju3ZfT
G17iYz5Nv993L5iXdWU+4pP0v7ar4R9O3DZ1
         "]]},
       "2"],
      Annotation[#, 2, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz0krhXEYhvH/kekgltIxZsqCTDl8DVsynJUU1vbmeVpQlKKUpSTyEZSk
DBvlUDZKlJCQ31lcXc9zP/f7vr0ViZHO4UgIYRRnGSGUZIdQimLUZYZQxl1c
xfVcyQ2cwJ353DPV3Gi/zwohiWC+kNfIa/Ege0REfimPma856XYlq7CXo9fe
hObU+9CKFvRhUK+d2zjOce7gIb7hW0SRgzLZYOqdPMGZSIv6jn3A/MQH+NYt
5G7ZOufpbPAzDvHjXsQ97puc777FrzjCn3uM+9z7sW3+4E984cU/zugcy6f5
hGd5h8d4N/UNvV/84U1/Xn4qn+NFLGDPPs4TiCANubJ3/WXzCpawhlXsu03y
FNKRgQLZr/4/RgA+ZQ==
         "]]},
       "1"],
      Annotation[#, 1, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0clKXEEYQOFqtCdFux1aRFRwIb6PoNEWEdqAhEh8DXGeBQVDAkqCMyKC
BFy6cSWJoMtssnEjDlHE4avF4dy/DrequLetNNL5JRFCGEVHKoTGTAgt2RAq
0iFcea5HAZ/N7Xqei5yxlkYKPeY+DtpPz7Xe/8Efza2cMP/iV2ygxrzOg3oL
B/Mx/8f3eIb5G5f0Zn6z9xHf4Cty+hoP6E38oh/yNVZRpa9wv97Iz/oB/8My
KvWleGe9gZ/0ff6LRVToC1zUC/yo7/EV5pHV57hXr4/31nf5ArPx2+gz3KPX
8YO+w+eYRlqf4g96Ld/r23yGSaT0Ce7Wa/hO3+JTjCOpj3GXnudbfZNP4tnW
xuK+1uowFPfgPHLxn5kvuTfel8vNv7mM/3CWc6jGMJL4hCq8A/2UP8M=
         "]]},
       "0"],
      Annotation[#, 0, "Tooltip"]& ], {}, {}}}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"RMS Fluctuation angle, \[Theta] (\[Degree])\"", TraditionalForm], 
    FormBox["\"Propogation Efficiency, \[Eta]prop\"", TraditionalForm]},
  ImageSize->{581., Automatic},
  LabelStyle->Large,
  PlotLabel->FormBox[
    StyleBox[
    "\"Expected squeezing level, white region is 0dB, darkest region between \
10 and 11dB, 1dB contours\"", Medium, Bold, StripOnInput -> False], 
    TraditionalForm],
  PlotRange->{{0, 10}, {0.5, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.455469282284444*^9, 3.455469333561644*^9}, 
   3.4554693651204443`*^9, {3.455469457534844*^9, 3.455469491277644*^9}, {
   3.455469558279644*^9, 3.455469567967244*^9}, {3.455469605563244*^9, 
   3.455469640167244*^9}, {3.455469853638444*^9, 3.455469862561644*^9}, {
   3.455469956208444*^9, 3.455469976972044*^9}, {3.455470029512844*^9, 
   3.455470079292444*^9}, 3.455470476215844*^9, {3.455470524388644*^9, 
   3.455470563841044*^9}, {3.455470599284244*^9, 3.455470631435844*^9}, 
   3.455470685146644*^9, 3.455470742289444*^9, {3.4554710829760437`*^9, 
   3.4554711239416437`*^9}, {3.455640198825116*^9, 3.455640279227516*^9}, 
   3.4556405731471157`*^9, 3.455640726479516*^9, {3.455640771735116*^9, 
   3.455640797958716*^9}, {3.455640837816716*^9, 3.455640874944716*^9}, 
   3.455640919841516*^9, {3.455640957562316*^9, 3.455641080864716*^9}, 
   3.455641155853916*^9, {3.455641196725916*^9, 3.455641213979516*^9}, {
   3.455641247535116*^9, 3.455641279624316*^9}, {3.4556413492627163`*^9, 
   3.455641426919516*^9}, 3.4556414750923157`*^9, 3.532055594658119*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd03k01esawHHDpszD/qWMYcuWpJxTRHiekkhyKkNddSnJpkwpJWlSicyd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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"RMS fluctuation angle, \[Theta] (\[Degree])\"", TraditionalForm], 
    FormBox["\"Squeezing relative to SNL\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  GridLines->{{5.1}, {3}},
  ImageSize->{581., Automatic},
  PlotLabel->FormBox[
    StyleBox[
    "\"Squeezing level as a function of \[Theta], for given propogation \
efficiency of 75%\"", Medium, Bold, StripOnInput -> False], TraditionalForm],
  PlotRange->{{0, 10}, {-0.1601458373248492, 5.077177266067502}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.455469282284444*^9, 3.455469333561644*^9}, 
   3.4554693651204443`*^9, {3.455469457534844*^9, 3.455469491277644*^9}, {
   3.455469558279644*^9, 3.455469567967244*^9}, {3.455469605563244*^9, 
   3.455469640167244*^9}, {3.455469853638444*^9, 3.455469862561644*^9}, {
   3.455469956208444*^9, 3.455469976972044*^9}, {3.455470029512844*^9, 
   3.455470079292444*^9}, 3.455470476215844*^9, {3.455470524388644*^9, 
   3.455470563841044*^9}, {3.455470599284244*^9, 3.455470631435844*^9}, 
   3.455470685146644*^9, 3.455470742289444*^9, {3.4554710829760437`*^9, 
   3.4554711239416437`*^9}, {3.455640198825116*^9, 3.455640279227516*^9}, 
   3.4556405731471157`*^9, 3.455640726479516*^9, {3.455640771735116*^9, 
   3.455640797958716*^9}, {3.455640837816716*^9, 3.455640874944716*^9}, 
   3.455640919841516*^9, {3.455640957562316*^9, 3.455641080864716*^9}, 
   3.455641155853916*^9, {3.455641196725916*^9, 3.455641213979516*^9}, {
   3.455641247535116*^9, 3.455641279624316*^9}, {3.4556413492627163`*^9, 
   3.455641426919516*^9}, 3.4556414750923157`*^9, 3.5320555947881265`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"0.815", " ", "0.75"}]], "Input"],

Cell[BoxData["0.61125`"], "Output",
 CellChangeTimes->{3.455644191388216*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dB", "[", 
  RowBox[{"Sqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", "0.815"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", 
  RowBox[{"ASqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", "0.815"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.455643298120116*^9, 3.455643353905716*^9}, {
  3.455643388771716*^9, 3.455643399270516*^9}, {3.455643818323216*^9, 
  3.455643845250716*^9}}],

Cell[BoxData[
 RowBox[{"-", "6.004736904302419`"}]], "Output",
 CellChangeTimes->{{3.455643301006116*^9, 3.4556433541085157`*^9}, {
  3.455643395666916*^9, 3.4556433995513163`*^9}, {3.455643821813216*^9, 
  3.455643845798216*^9}}],

Cell[BoxData["14.223738729032537`"], "Output",
 CellChangeTimes->{{3.455643301006116*^9, 3.4556433541085157`*^9}, {
  3.455643395666916*^9, 3.4556433995513163`*^9}, {3.455643821813216*^9, 
  3.455643845798216*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dB", "[", 
  RowBox[{"Sqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", 
    RowBox[{"0.815", " ", "0.75"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", 
  RowBox[{"ASqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", 
    RowBox[{"0.815", " ", "0.75"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.455643298120116*^9, 3.455643353905716*^9}, {
   3.455643388771716*^9, 3.455643399270516*^9}, 3.455643859885716*^9}],

Cell[BoxData[
 RowBox[{"-", "3.583413897937469`"}]], "Output",
 CellChangeTimes->{{3.455643301006116*^9, 3.4556433541085157`*^9}, {
   3.455643395666916*^9, 3.4556433995513163`*^9}, 3.4556438603332157`*^9}],

Cell[BoxData["13.028747310641123`"], "Output",
 CellChangeTimes->{{3.455643301006116*^9, 3.4556433541085157`*^9}, {
   3.455643395666916*^9, 3.4556433995513163`*^9}, 3.4556438603332157`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Having a look at the state with no phase jitter", "Subsubsection",
 CellChangeTimes->{{3.455471343629444*^9, 3.4554713736906443`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dB", "[", 
  RowBox[{"Sqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", 
  RowBox[{"ASqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.455471228688644*^9, 3.4554712607934437`*^9}, {
  3.4554716913110437`*^9, 3.455471703011044*^9}}],

Cell[BoxData[
 RowBox[{"-", "5.0771772660675065`"}]], "Output",
 CellChangeTimes->{{3.455471243649044*^9, 3.4554712614486437`*^9}, 
   3.455471333957444*^9, {3.455471693167444*^9, 3.4554717034322443`*^9}, 
   3.455640198949916*^9}],

Cell[BoxData["13.87698389579345`"], "Output",
 CellChangeTimes->{{3.455471243649044*^9, 3.4554712614486437`*^9}, 
   3.455471333957444*^9, {3.455471693167444*^9, 3.4554717034322443`*^9}, 
   3.455640198965516*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
And after phase jitter of \[Theta] = 5.1\[Degree] this state becomes\
\>", "Subsubsection",
 CellChangeTimes->{{3.455471394251444*^9, 3.455471426574644*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dB", "[", 
  RowBox[{"Sqzfluc", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "5.1"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", 
  RowBox[{"ASqzfluc", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "5.1"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.455471508755444*^9, 3.455471550157844*^9}}],

Cell[BoxData[
 RowBox[{"-", "3.000291861471031`"}]], "Output",
 CellChangeTimes->{{3.4554715396590443`*^9, 3.455471550594644*^9}, 
   3.4556401989811163`*^9}],

Cell[BoxData["13.842968866972615`"], "Output",
 CellChangeTimes->{{3.4554715396590443`*^9, 3.455471550594644*^9}, 
   3.4556401989811163`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"dB", "[", "Sqzfluc", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Theta]", ",", "0", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Eta]prop", ",", "0.5", ",", "1"}], "}"}], ",", 
    RowBox[{"Contours", "\[Rule]", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "10"}], "]"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<RMS Fluctuation angle, \[Theta] (\[Degree])\>\"", ",", " ", 
       "\"\<Propogation Efficiency, \!\(\*SubscriptBox[\(\[Eta]\), \
\(prop\)]\)\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", 
    RowBox[{"ContourShading", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"11", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"10", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"9", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"8", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"7", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"6", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"5", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"4", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"3", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"2", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"1", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"0", "/", "11"}]}], "]"}]}], "}"}]}], ",", 
    RowBox[{"ContourLabels", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"ToString", "[", "z", "]"}], "<>", " ", "\"\< dB\>\""}], 
           ",", "15", ",", "Bold"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Which", "[", 
            RowBox[{
             RowBox[{"x", "<", "0.45"}], ",", "0.45", ",", 
             RowBox[{"x", ">", "9.4"}], ",", "9.4", ",", "True", ",", "x"}], 
            "]"}], ",", 
           RowBox[{"Which", "[", 
            RowBox[{
             RowBox[{"y", "<", "0.51"}], ",", "0.51", ",", 
             RowBox[{"y", ">", "0.99"}], ",", "0.99", ",", "True", ",", "y"}],
             "]"}]}], "}"}]}], "]"}]}], "]"}]}]}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.455641457230316*^9, 3.455641489225916*^9}, {
  3.4556415234055157`*^9, 3.455641533358316*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1fQVY1M/z/4GAoCjdHTbYhTVrYrfY2N1+vsrZ2GIrih0oiopgY2Bgi60o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   "], {{
     {RGBColor[1, 1, 1], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtVUtvjVEUPfe77fnOvcLtw6OqGoSOiLSCRIiJiZiIkTCQGGhEokNSUzRe
fXmlJISkQrzjUfWIgX8gITHwKBERMVGq9aq1stZg5+yzv33O2Xvttfc3f3vH
pt1ZCOEJpAhZh81EIYQt0IdgeABZif2MFMIw9OlY38FnNmQc9psxhEboP2F/
i7UBMgZ7N9Y78E/Qb0T5j8HnepTPD+jXoM+C/h36Zuh74Buhv8lsx34O1vWQ
nUGxDDseSidkMSQl6Vtwx4GqEPZD9mJ/K+r8eNJ9KyBLgvzoX5OHcBX6TNhH
k/Jg/sz9kXNfB79yKYS/WE/C925RebVif6+oPfX2aul8d1FUfLtw/1piA30D
7jyMuAawbyvINmb7PtjqIc+Dcp7lOBkTY6uJ8iVuq4Pwok9tVK3GXa9VxLUg
n514exT7aqwtWPdAnsFeQYz3HTNzY41HYF9jnXHXJ/nUYc1LirUHb03BHZ8h
Zb/z3W8R19GCYq5JwqU2yfbN9k/wmQeJkD5Ib6bcmNMq50UMd1QL31c4fwh4
5Yj/A743Qf7hrstRWNWVhPch13p5QXVv83rA+sEq4U69y3b6cz1oO9/kGXJ1
EPdXiG1JtRqDHIdUsM+xnsf3qlx3vUSMp7CfxLkp+H4iiifkS69rk6AfjcIr
Qu+OwpO4jmTi3K+C3mC9lkE/HIVdNXxeJMVZzMXJI1Xi5bmoeBjXGehF6FOh
vzauxH0I9gXQJ5P6hP1FjrEXyUty73YUthPwuQO9GfrvpD6kf56UA3Ppw/d7
UXX8mxQf4zwC2+MonhVgewh9IYdKSbgQn9OwhVxc35rEgaWQZph7MvGSnPyY
KYYMUsLZ38QGZy+YfzWwpVxnn8LWkcl+F/e8z9TvfwrCgpicdX4bIXvhUzaO
c/G9P+p+vkNOfSWvIP2Z+ERufMmUyzTznngOBs0y4ljvWr025syjx7mRQ+TS
pah5R67XRfXrbONPHIlnY1TcczzrOLOozzB33ngeTsvFy0oubo6an8xjxFzq
dK1Zc2K5GdIVxLu3ns/spSZjwtq+8zzvNwcrQX3BnmS/1Bsb8oe8++Re5nuN
npn83uI5Qx5Qb47CbqFrxJp8dH0/G8+yuUKfuZ6x7Z4D/N5uzNk/xOKYe/SL
6/LTs3t6VB+zduxl3tfhd9kzQ57n7NH35gl7g280mV9l+5Nn3F90f3/w/Fnj
fw+xXW/cWa/o+XYqqEeH/f+oOEZi0u9aEd/MPGdd2G/UG6K40+2+YC47jD+x
oM68cmM/aDwzv8seZk1nmte/HBvzZtyc84xxm/15J99qNV/2ub78XrRPnXvj
StQ/pOJcWJPcMZDrfZ47X80BcmHA+bKP6NPjvJabZ+QYz/S6d9iT7M2GJFuf
/bt9lnGyj1k/8pbrH+uT5jTxPO4e5rvk/qTt/wGWfgaD
         "]], PolygonBox[CompressedData["
1:eJwlk1uIzVEUxvc5Z6z/H3HOzJkZx2BCLo+Sorx4mZQ3KcyQpoaaNDKPI56R
M+7XUEQRuceQS3n04klMUe5pEh40MUkuv6/v4avv22vtvdde69uzevpXbS2m
lJaDBlDOUjrJQh0xHv44UlqAbgVX4JUwfw1WE3+GXgafCq7DS6ztYu9O8DxP
6SlrS4nVwLXwmTpbOS+ID4Pd8G2FlLqIv0IPoh+WUppAbgb2oO+gy7lzlKu1
l+g68XLJNebwCthOfAmYG96jvUOgAm8K1/IWrCX3CXoxfAq4Cm8M8zdgDfEx
dD98DngA/wsG4PPAI3gzZ94vuWbVfoK1f9zdSXwEPghGC75Dd23kzC/wMriA
3oT+Bq+CS+hJ6EXkj6I3w7eAn0XPZDK8E7yD/yLnIPnjMucqR7ld4D38N/HD
xNejPxZd03H0OvQH9B/0UfQG9Cd0CZwK90S9GSO+P9wD9eIHei+6iTfeLbnn
6n0vWFjwWpVYX+beqyct6B70Z/ZPBOdUD2s74APqEXoYdKDbwI2wp+Qt9ayO
7kaPoDNwRv4AK+DTwE14New99US92ReuVZ6T9xpzz141qtbvrPUSmw3uwU+H
394NvsLPhu9SjnLPh2uXB+SFi+HZyQPywvTwWXqj3toSrk09Vq9blVP0DDSL
Grq96J6r91nuXsizOfxYeDYrdQb8SHiWerPefiA8G/05/b1a7r/Swdr8sOfk
Pd1xO/wmvW0mGAqfqbNV0y14WzimHqvX7WFvy5Py5oyw9+VZefdQ2HuamWan
P66/rj/cQLw5PEt5UF68HPa2Zp7Q/wE0kIyj
         "]]}]}, 
     {RGBColor[0.9545454545454546, 
       NCache[
        Rational[10, 11], 0.9090909090909091], 0.9545454545454546], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmWuMlsUVx5/33feZ5+G23BbEcllXQWxVUm1FWJB+MhHTxKa6LOtCETBi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         "]], PolygonBox[CompressedData["
1:eJwllUloV1cUxu/75/+/7yVRM6pRE5OIcQJBpWit4NpFV4JYqqh1IQ7QLoQu
unCAGqc4JraaNo7VKm2dtSMU3QoiiFGhVm0dkarRaJxi+/v6LQ6c757vnHvf
mV7j/E+mf5wLIXyG5JHK4hBGFFCSEA7GECqQu8CLGLuzEH4FT0F/D2kBl4Nv
Y78AfiqM/zD8X3G2B1tZGsJaLliJ9EMfAWcytk+LQhiJ/hOcSfhORNaC94KH
JY6hWNvA/cEDwCXgCXCu4TuDs3Ho65F38e1D/H1wh0a//RVnCfwD4CbwcPwr
wK3gKnA1uLjYPvKdAP9zYi3kjU/AM5E72DI4lXAfEHZz9Bv1Vt35M/gN/B28
px3pRd+C/QLcqdi3opfiX4N/F2dfwF+lHBF7F/zmzG/S23qx78fehX4mOMcb
sD8nZivcNqQHfShnZ9Gn8Q216GX4N+DTg89O/J9zdhXfMuyHwQ+xHQ/O8Tps
Kfxyzu5zthF7AzG/5z2l2OdiLyD7iH8dexn2Avw+Bdd4HbgTfRp6B/ybcGs4
6wbfA78GB/g9edfwF2zjkPPEW4rcSF0T1UY1+Q3bl8igxDlSrr4C1+rbwH3B
bZlzWc0bW9HnY38feytn18CXkYPgQ8S/gj44OhcPsfdmjqFYemM7tkvI9sTf
3Ji6p9XbpTqL7gn1xj/wt4JXZ75bOVmjXkN2wp2JTNS3wR0T/I1N2Gqje7+b
mP+C66Jrq5woN52cdRBvBZLn/shZv4JnrAXuLqQ+cU1V2xT+t8Q+gETVD5/V
Oce4Cv4munfVg+rFQupZ244sSu0j3wKcD6JrpFop5yfAHaox3AXIY/SbqWul
GQ3gF/Cv5z0zR8Gzsd+Cm+gOcDX2FvRnSH/lKjp3f+DTA94RzZ2DPNAsI4+C
Yyr2BnDfxDlQLlRT1fb/nHI2h/vu5PzGr+F+BL6HPh7ObvBL+H/lvSOOgUdH
z8ZypB7bpuhZUM+r9/WN+tZG5HT0jGvW65Dj0W/UW+uRk+i/qyfwXwPONN/a
iYl3gnZDLvMsa+ZLo2dCs6EeU69VgLtyrlk5+jzkzyL30GLsb1PvDs28Zl85
U+50xxHsszLXbhQ4wK1Rzoi1GW5dsUW6alCCfVD025Uz5a4qendpJ2g3aIdq
l6oGbdE5VC61Y7RrDkXfpX+A/gWbMu967ayN6MMz51YzOBbuktS1b0eatMuj
Z0MzORnukOhcq2bz4JZkntUBqg+2Z+DOvHvgh+gdpF2kHT8evTJ6V4kjrv4x
+teoJt9hK099d8rZh7oLac55h2uXr4+ebe0w7bKi1LOnf9IlYr1IvVu1I7Ur
KzPXWjWrQh8Y3RvqefW+/jn696iG72TeMdo12lmn4J4jxrLEO7oOW0P0t+pN
zal3gnaDZvxH2aL/Deph9fLfqf+N2rFJ9Dfp27QDMuz/AS4d648=
         "]]}]}, 
     {RGBColor[0.9090909090909092, 
       NCache[
        Rational[9, 11], 0.8181818181818182], 0.9090909090909092], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFl1uMVlcVx/d85zv7bMCmEtPgTKUFkU4bb6htqSm2tcSZMA9QmxRiY1pa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         "]], PolygonBox[CompressedData["
1:eJwllWtolmUYx+/32fvez23z+EFkWx6mmQQec2iRRyQFPzgT8tSHzFTIPBQe
gpS+6Ka5nFNLFBQKxIn0JRFJxEAUQZ2kgik4llOaVOoy1CSc+vvz//Dnvc7X
/Vynt3rx6jmrshDC56AInuYhSNAN/Af9O/isLIRx6F6UQrgDNkF3IpuaQpgP
bhRCWA1qYwhrQG8CzUR/Gt+30N+G7o5sOboJYGHBNkvQFUAfco2Fr4e+gr4R
fTOySvxHwrfgfwEMQV8FfoGegU0F9EjwPu/5Ctko6HbsD6E7jv9w/N9D9hzd
MOJ/Cb0hmdab9fae3UIYwDc9JsZ+fLug9+B7EJ9e8G+AM/oW8Cr2K+F74X8H
/m34n8jRQaxV+FUQ611ku4jVhH469CjsL5W5hm3YvomsFXoeNmP0NmTrydcD
dEGPj47dDsajv0/cH7A9Rc5O+Hno15NvNPwm+D/w2YDtRtAB/b9k6PphcxTb
u/A/Fl0T1eZKyb38Dlkbuh1gAvRQ8n8DXYPNtTLHVOzXkf0K3YD/ZXwz+O/L
3DP17qPcs/KUmIugdyKbrFoje4R9G1gS/Aa95WD0t/4FNsOfjM6tGmyH/zr6
2z4lx03ijUW2LLhmNdCD0JdDP8J+OfrzxN9Y8ExUoo/I6jLb1EMPSO5dOTH6
Q88GXfCf4DMLelL0LG8DnblrrFq3oH+C7mcwJPNObEueQc3iRTAiuufqvXoy
F/5x7t6rZwn+z9yzqRpk8E2av8w12gU9ETQXvBPvoF8MthQ885r97sSvJP6/
+O+Fv4l9o/oLfwH5h8jqsK8Hfcn1DP3f6Cvhj0X3TL1bS7wQ/Y361gbwD/Sl
kmM14dOK775oX+VU7nXIBhdds9rkndZu6wboFryC7Aj8Zt0M6Ibk3qpmJ4g1
O/o2aEcWJNdctddOzoEuJe9aX+yL0NXRs/uMnBn5K3Lfgh3IlkbvhHZDN2Uc
fBX6w+gngaslQ/QX6Avapdx0Lf63oa/jv7XoHdYuHwD9C74BugW/8Tstc0zF
HpR7VyWrzv2N+lbFuJE845p17UQ5sT5Ovj3q6Qr4I+AB/BTsd6N7LXl2EvwH
6BYl30bNuGZdM6/ZXwFaodtz924W8W5BTwYtmXui3miHtcu6mbqdd3PfAt3E
ayXXVLWtwWYr9LfJb9EMahZVY9VaO6Pd6Rc9a7ohuiXaAe2Cck5B/zD37OjG
dRC/Gf29zDekEfuK6FuqGdQsVkXfhofwz3UvomdVN1G3cVl0b3VzdHtkI1v1
5Hh0z9Q73aBh6EZH10I7MhS+Lvm/Q2/QW3QTdBs0kwOja6xa64YPxPZs9H+H
dki7pJnX7GuHzmn3kmulnql3LwFfTupk
         "]]}]}, 
     {RGBColor[0.8636363636363636, 
       NCache[
        Rational[8, 11], 0.7272727272727273], 0.8636363636363636], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV1uIVVUY3uecvdbeIxRWjqD2Yo4TmBfIGZrRMS0ds8TRGc0aSMJbWHQh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         "]], PolygonBox[CompressedData["
1:eJwllEtslVUUhc/9773/f2yigQBKcaCVh4a2mhgIllsemhQIBNveFggmKC3F
CAEMjxEkGGBASMDHRKoSnmJMGAADEhjYTmgFtKIDE1uwTYwBpZRXdKAQ4Fus
wU72Omvv89h7nV3V/mF5QxJCWIcVsE1pCMtzIZwBDMcQ/s1C+CwfQhtr/+BP
he8F92Avwv8MrmeDb7AO/Grse7idxK/Af56Y78Ckhgn4Jex4zmfUaS+IMvxJ
+JvFEH7ERgefURW9Ju4+eDH4AbgPfJ773QNPJf8MZz8NbgO3R/s6Q2d1wnfj
f0De+KdCOMxaE/wJcl6Au4ud1V2xO/h93KkEdxwbD75MXh3+Rs5/hH+dtf3E
lrFrehT7Hcj7ThXkrgWPK/hMnf0LObPI/xp7DvwX1go3QM5rxLaRsxicEZfn
fqfhS3C17LEbbhn2MrgAfof4MvwV9rqKteLXw9+Ev4HVwzdj3dzlAbiM/zf7
fgo+R/4IeC85o8Cj4Pfh/wG/A3wLPDe6pqrtbe6UwM9Kze3GRjJr4IkWwPOI
XZi6N59j/8G9Au7Ou+eV0Wfq7C5ybsP9qf6D2zmzn7Pvq57EdoHvgN9PXdsK
/AL1eDW6Vqr5r6zVgn8Dt4Cr8evI70lc8zXgJdF7qSdLo3uu3ncQ36DeEt9L
/GrsRtEal9ZVA9VCb9bbVeMW/AHWFuB/xH4J+auIf4b4zcRXw19gbQb8UexZ
cBM4D5/DlhG7EjyF2CO6Y+YaqVZ68/+ZNSFtSGPSmvbQXm9gl1L/Kf2tZvY7
yn6rwMcSa/Qn/HdZqyi4JjX421mrKvhP6W91srYAfIj4sZk1JC1JY0uJfSn6
ry7CalL3SL1STWdm/gP6C/rjl3V29F3eAh+SVlh7PXHP1fvN2MmcNdkRrUlp
cxgrwf2Q+m16g96iHqvXDdRoNXgPdjdnze+KnjGaNZopmi0TM2vnbfIn4Vdm
ztUfm4D/kL3mF/xmvf33zG/T2n7wJ5m1rxnzceY/pr+mni2Hn5daK6rhluge
q9eN7F+DP1i0fwqbDN5GTFLwn9sqvcOvT6wxaa0/tValeWl/DmungmPm6n9F
10aaWkdsU/TfVUyj/m9m7WlmaHZIs9KuZnIkfijzbNIMGcx8J91NmpV2x4AP
Ju7RpaI1KW3qzo2pZ6BmoTQkLWkGaRZJs9LuF6xNg18E/xX+e6m1PF1vlP6w
w4n/wMXUGpPWlNMD/jI6VzGKnZ161kojb8L1Fb2X7qi7SlPSlmb0Efyh1L3W
jP8WfCvzLNJMK8I1RM8izfBr7PUYhFLYPg==
         "]]}]}, 
     {RGBColor[0.8181818181818181, 
       NCache[
        Rational[7, 11], 0.6363636363636364], 0.8181818181818181], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1l1lsV1UQxi/9/++CDyYaJDy4ABojS6EtJooGBNewqriABrAoCUIrRWNE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         "]], PolygonBox[CompressedData["
1:eJwtlGloz3Ecx7/7H7/fbx4owgNHDGkXOaZYEXO1ZZaJ0JYjtTna3LMHrlDE
KMu5zZgHjkTyxFEUxphzW7bFzLVhRSKlEV7vPnvw7vd5fz/H9/v7XHFLC7ML
Qs65PBABkz3nFsc4txpyK3DuGliJfBOjMb5zV+E5ITu7jjwVfA+bTxryV2x2
w3PgX5BnctYJz4OnE/urZ7FncnYb/Sz4QOS/xNwAP419FvoS7KuQ74EieC36
iejro3x551HOWtHd4SwT/7voxyFXc7YqZD73kd9gX4j9ZfhneP9Y53Zwtof4
T7i7Hp/F+D/C5hDya86q0J3Hvh376fA+6H+BdHgbOBMxmxZ07+FV8EX4NxH3
mWdvT0HuzV1L0X/Edw36Jci1nt09En0v9DXw0ei2w/vBc+Bx8EJ4X3gT/HiM
3aG72uAX4FfgHfBG7LKwr4S/gztQwX0F2Pzz7Uw6xWhULPhO5AzOypA3gWER
q4FqcRKe7awGp5BvgOshq3kH+gPE7KlcEGOvb2/W2xXzAfpWsADf+eAMvom+
/bvOzqoe6BciXyLeUHS7QCzxXmLTHd2rqOVSOVaudYfu6oFNCfI+3+R4cET9
gM8kYp0DJ5Qf/HND1oNRz3KsXCvHD+ETPOvNi2AS9hnwfORakBlYT6m3ZsPz
0MXDnxOrHoyGjwJ1YTuTTj2sXlYPqhfHom9GbgRJ6FPhn5DbQSr8WGC5H8x7
qtF95m3LeO8tkIL/eFDp7CwV+Q/6zchNIAueDV45O5vjW4+oVzJ4b65nNrIt
Bj+i1tPqbeX4sG8zpFkaxBvW8ZYWeAG6GpCM/xDfajMDNEdt5jX7vbDPDyym
YqvHunn2Zr1dOW/r6nn1fhp3PkX/Fnmrsx4agW0R+BeymatDHuBb7Up5f4Ny
53XdHbZcamdod7wApdjODWxRNcK/Ra3H1es6m4cuH/vYiNUoAb4CJIQtp8sD
q4FqoZkc79nO0e7RmzYil4OksO2sg9JFrVbK0RF8awLbNdoxP/F/hH5bjM3E
fux/+/Y29VQn8uDAcquZ1mwXBfYvmrniwGqgWujOMt9yrFxrp04JbAdpF2mH
tXDX8MB6SzOaHNhO0m7SP04j/hbPelk7az26tZ71unpQvZgYWC9rh2qXPvas
VtqJ2o3lgfW+ZqoisBnWLGtmNbuJnvWa/jlO8wzKIraDGqK2Y7VrtaM+eLaj
tKvUA+oF1Vi1lo98/wOH1OCc
         "]]}]}, 
     {RGBColor[0.7727272727272727, 
       NCache[
        Rational[6, 11], 0.5454545454545454], 0.7727272727272727], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVk1oXVUQvi/3vnMPgm7cVVyICVYRQcXSjWLUBmzfi21Si5BaQdEmkhcX
9rUpmCJKXRQjWFM3aRIhIhjzEiXR2tQgVK2SLtQmoUVbE00rmkJojW4U0e/L
94mLw5k7Z+ac+flm5t705HMtXXVJkvyFlWKNxyR5IkuSMeyNOBjB6iskSRn7
JNZwQd/3F5OkGfIb8yR5CvzPci3SJ7HPQ2Ye9Bz2XsiuS0VvAq+GtQu6JewT
WF2g2/Hmx6Db/E6r36JOFfQoZLZg/wBrCLxb8EYneAu4uwm8Max+8CewDoDf
i7Wayp4B0FPw51m+gb0CnX9Ad0J2Gqs5lUwLZI/R54LsoD09iWw5Xqd7KXuq
IPlfcM9R7Btgy1bwH0ll50ydvknvxVmFPmA/BPmr4L9q2WbLNPub934J+/bC
ti+w12ey8xPI7MTqhszjiexjzHrMYy7IvxAU00vQnQXvdcjdBvpikA+/gn4e
qwbZ+3LF4fZUuToblJufcL4fqwHv7sPejvUa5O/OFZud4G/Dngf5zhiMRvHf
w34+KE/rIX/OuVkC/3vz3wF9GWeP4c13o+4iXUmEkRtS+ftGLvph6E06r8zp
lVTfpPeDLmXCIWPQaEyST5qxYc6oy1hVnYtm3DkQpXsU+x6/8XTU/ddn+h7E
dxn0bBCOpp135qea6Zt3lG3DSeN/BfJzqewoJ7KFNGWY+6lMsetzPbAWGHfS
Z4vyhWfM6ee0D/K/B73Hd0edd2KC95eMj7ZEOKI8sbQxKLaM92RRdjP3d4G/
Ffz1UVghZs7j/HBBfN7HWiq5Nrsz6fL9VuwtWJvrdCdrmzZ9i3texP5NVN20
uHZYw62uHeKW+WauB3JhbxD7PdBZAL0B+0RRddKRqU80OT6sv+2+pzNTLdcK
6h9l20ld8olXYn/O8SfuacMizu/Idc+PoP8O6i1fR/UU+sQ4sm/RF55tcb9h
r6EdtUx5GctEV0yPZ5JhvMfM5/mY+TOZfGL+WXvMw6kofm8qPN+bq3f0BOWP
OFnrXdhPGDPXQLYDa6UgTHXbR9o64z455XcGjIuScXIG91+E3r5c9cw4HY/q
nSX3T9oyY33au2affaH/9Is9qd79c8g47XSdtTnvjOWOgt5vNKa7XbvTdZJd
DsrlCdgwV9S8WQT9UdQ8OIb9jyD8fRU1izZ5HrHnMh6XobcUhLcaZJYKsus0
zn7L5c9qrvMR9wFinPhgTJaj8HAJd/Tl0j8YhKMOY6w+FZ937g7SXYBetag+
WXE/HnEfoz7lx3HfnqJiTt0Gx439jXNtnXvdvOcc6QeiZsRDUXOBNcecDrpe
toN/XRAODuaqP9Yh8TRu+18Jkr05092s3UnX6UuQyXH2suug5nnJmNE22jnt
OTzhfjNnG+hH1b5wJwa/A304ly9Hsa8auy8E3U3sHHBNVf0/8KBnCmcL5/lm
11jNtUI8fYiz3bQ7Cm/zjg/7xFsFYYt2UqbN2K24Rlk/rIUzvr/V/Yp+M5en
XUcr9odzbZvx0eWeyd45bLx0uW9fdU19GvVv0RgUk4ZU9/R6thOXa7Gvk93U
W7Uuexv7FP2n/BXX/qL/t+bC/32Tcbs1qi+3O6ec2czVtUGx/7MoHeremGte
cm6WomzK7S+xSizWu1exL9FPYrJqPmPK2HKOsIfzP5B183ZUz0+DZgbr586g
+qA/9Jk4IRb/w3WvMVlyvZXdN2j/vPvCDr/FXkwsLvsfbcL9//1c+Xo0KIaH
HLc3c8X8SK7eP+z6Y4+c8uzjjGddduPOn6PkfgDvQlE0eUd8z2wuzLGvED+5
88n4tkbFuwzdfvdt/kPxn4az6ZxjT13O9yZjcZfrhTGvGJv9tpN10eG+yj7C
fsL/NWK0xXlgPqi71nOi/kmeifp/4kzifxZtHnIsKVv1W/8CC8eZYQ==
         "]], PolygonBox[CompressedData["
1:eJwllEtIVVEUhrfX4z6boCbNekEPK6OCjKJJkL0GdS31WgQFQVFmmRbotaCB
9JoVZNEkjQY1yLpaZKmZNFGLJpUaSmYGGoSBVLdGEfT9rMHi/Gv9a6+91+ss
PFRTVp1wzpUiETKe51wV3zaUb8G5U965LhxSyCR4LTKU69y1HOcqwB34HMN3
P/wTcG/s3G74EqQPXI5tJbgK/xT4HdKA/wf8d8DPR4rAu7hzHrgbvgo+g/9p
4l/EVgfOJ8ZN8Fv4uoTFeA/+y3sr4WYgs/DfgywBx8h5/AdjOztJjAFwA/wL
7pqL7Tr6VmL8BF/FtgVcA9+ZsJyeBctBubzBthH8GtsZuB7i1eO7HNvOhNVs
GbgQ6UFvh6+F/8T7kuityCK4L3lWy3akAH0V0gEuQybwn0Lfy9ky7rjLXU1I
EnxWOcDleuNSyD24S7HlrhqpVqqhalkMfzuYj3wfE38p3DTnD4OznHkJdxl9
Isdq9gi+FdvByGqgWqgH6kU5+mr4B/AHInuz3j7o7S69sRmu2FuvFfMG/IXY
evGRN82EGyX/O3Dj2NYpP/g54Az8LfAw/DZityAL0Otj691JJA0eIcZ2uAxS
6a0H6oVy2gDfSczjkc3QlLeaqXaaWc1uJlitlWMb+Ku33DTjmvU+bOnIevwH
/bPy02wjJ8At8KUJq8FDzUKwt+WrR+Aib7XVTG0OdkZnNQNj3nqu3ivmGLlm
0a/g20T+sbeclJtqMOytBqqFdmQI/+955tvNfdPE/41PbWQ7p91rx1YR2Qxq
FpPBZl01boxtR7Wr8nkKPsf5/hyL0YveFWwXVMPn4P5gvVFNXgX7J+jfsI8z
1ZxdEexfUIIUoqfRF0e2883cNxBsd7Sz/+A3IT9yLedf8EfhZ0dmE3ck2O7I
VgFe4y12I1KAXh+s1tph7bJqoFooh6y3GdesaydHve2cdk8zM0Lt7gd7u3qo
XuofpH+R3qy3rw82m9pB7eJ/6civDw==
         "]]}]}, 
     {RGBColor[0.7272727272727273, 
       NCache[
        Rational[5, 11], 0.45454545454545453`], 0.7272727272727273], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlktoXVUUhs+959yztwMHceAsLVJQEQUVFCNotaNSqQO1xhpy2wasNoU0
gSioBZtUjC8cObHiQLCDmKSmqSZgqrTm1fpsnYh2YNGCVamCdar1//xXyOCw
11177bXX4//Xvtf17XtooFkUxXf6Sn1bk2QpRnNR/FoXxeOSb5NurFUUL+ub
aBTFHq3/VkWxW/Jp7e/VN6Gz3aX1yPck65e0TstuQmeel3639p+o7Ke3st/X
CuvGwv82yY/qe1dyl3y29H0umzrk7wvbcmb17McNyx8o7rZ+T2kdlu5Sw/a7
mrZ5W/Kizi60HNOKdMcbjrmvaRmbmZZjfV3yp/K1T/InWk82LeNvMnw8J5sD
iuuRyvJh2e2lnrVzQc/vqZZ/k9cfsumXj9+l26CzPzWcI/f3Rz2J4ZXIE789
2ntW6/amZXRz2pvV19bvkeQa/aD12quK4n7JtWI4IfudkT+9oA+v6uvQucGW
82Ufe/wsR8zkNCP9eMMx35D8+0atQy2fxceTyuUa+qr1jdJ13NFw7B3RG2pO
vfCD78moG+tU6KkNMvubSsezGjcr/aW34BDs0Av6QPyTurtHuvez4+oLPT2c
iRqCZfInd2JDT3/p4XTUEww/Vhrbw7X3b1e+P0veL/mW5PiWo6fUazZwOFpa
xv/1yfuHIx7qRU1uTd7/Rb/Xy3ahuYbBpcAeua1Uvm8xePS37j9YWs891KAd
PAIPOytjAt7QI+qJfU/42SI/81rPgOXa545Ivqk0n8kXv72RC3lybiK7loMR
P/zeE7xBXgnuTASnwBbreOAMXDNPzmt9MGYLM+Zits2PYbsQGPhNeyOK487s
s+eDF9TgVNw1nZ1vpTxGtL5Qee//uVX5TG9pPTnPZPeeeXaudl/oT7u0HfbU
7mjwCywPBXbBDVgBgx9l4+mY1l2VY6D2HWEDVqajH2DpbHYM32idza45taee
n8WsAS9zgRlqsBh1mAx5dUYthD3+iJl8wSV3fijfi9mzeH9tDtD38Wx+nAgO
MVdOx2wBO72Bjfmm8yFuMHgyuEMflmMOHIvc57T+ST20v1n3Z+09VXrOvli7
Z5PSb66Nqa9kv077N1fuIzXfUfr8VMwE+MRd3NMv/VvJuDyU3A/01PO+2hjc
na1jD/sDMfeYf3PJc4P5d3Xt+A5Kty7mBfltyY6NGOF6d8TTWTpW4oRn8If6
DGafH9L6ZrLN1to8IM7V/nRW9o9ufbWmXwp+XyjtE14sR85gcTY4De9OBXaJ
J0ddh0PXDj3vxV3lGj/YA+f/BB++VZyp9iy+nPyG3l3aD+9nV8j0pCvyHajN
Q3gJ9uEAtX4m2zfz41D05YHg7oXIhZxGQ95YeyYOyfZe2V2SfqPWI8kxTyXP
rrGY4fC1HRzEBzzAD+eOBi/PJmPmTDJWt8ccJ8aOeKPh93zowTp6MHxHNkbO
6b6HJV/hnSau2tw4zjzM7t1Adn2G4z/D5dqc4a2+GP+FmCXTyfV8qTZ26Bl9
uRL46YyPnKjdaLLPbbJ/OupDnZgB/cFrbDujF7x17fg/81dyH8A+93Af/P0i
Gbtfan0vG0vMzpXgNbWE95viDWVWd8e79nX2WXyQ74a49514I+j5Urw7vD//
Af9BXgY=
         "]], PolygonBox[CompressedData["
1:eJwlk02IzVEYxs+9/3v//7OxsZ+RLEgKixlDIUqJWDAjmbpjplyayVwjrEZj
7mAhWdlYsJKa5lsYGeSzKF9jIx+lmKJmJmVsKI3f41m89Tznec55z3nf9yxu
q+zqzIcQthAF4lMawh5AE3EthnCAWAg+j3YMbWUWwgQb9hHf4X3wmKDlQqiC
PxAp/D3+38UQpuF98CmiAf8Ua2N4Z+EbOLsHvZh4zylwgqeDvb3wq+gjrK0F
r+AOZ9DesDaB3gOfBPcTzQXnUK55PFX4O+63Ez6A3h3sGQR/Jn8/+a+jL0W/
Ef22MvpNcIH9+8GtxBi8Hs8jvG16L3vXwB+DF6EfRX8NLyXOqdwniIfotfAj
6PeISsFr0mbwN+ecYxTtLtGat+e+zot+Wy/xF38d/gd5e2bhw+gD7C+hj4Bf
oO8l/x3e8IP7DUVrevNX/HPoF9Bb2PMTPEh8ATewNgyuj651O/468En2PEPv
IN969EbW5tFriCvwanRtdcZp9YO1lsQ1UC22Zr6L1iYz11C11MxodlRD1VJ3
ylL3VL2thV/MPHOaPc3Ax9Q5lVs9vwzuRK8puAfqxUt4OecavAKvzjyb5/Cv
Apej364ZPhjdM/VuOf5L6IfhT3M+swKe5n7tefdcvf8/s4lnphO8MXp21UP1
cihzLZcQjehNqf/COvgo2tnUWDOsWR6PnjX18Bb4V+paPyeewFP4Jrybidv4
Z1gbx1/CfxytKzOWZzxzTuXWH9Jf2pG6lurZbvZ+K7oWOkNnbY9+u2q2Dbws
81/Qn9ff7059F9VgDvyH/YcS//EFqe+ku2kmNZtvo2dVM6PZ6YqefdVUtf0H
ubKVsQ==
         "]]}]}, 
     {RGBColor[0.6818181818181819, 
       NCache[
        Rational[4, 11], 0.36363636363636365`], 0.6818181818181819], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVEtIVVEUvb533z3XcYMsm+SwBtXAmhWkhBU0iCZNNcioLH0WRqRWL0h0
0CxtFtVA+6hNUvqoRX7KysdzUA2EIKiBEQQVWlBrtZY0OJx9993ftfbZ6+tP
7G/KRFF0HSeL8zqNovY4il7hflYWRcch90Nfibs7F0UPoWvAGYTcB/2pJIpG
8b0I+x7ommLZULcqKxvqGOca5GXYtyDhTCodYzL+mqzytuJfHroKfBcRoxZ3
DU4jfRyHdfFQx/jTuI9kFGckKE/CPLCd8r9f+M7jHsP/LOJtw8mXqS/mY65l
52Bs1jjtmJdgOw19gX7wH2BPqP85/CZx7pepR/bP+haDfHa4xxn3nnXOt5Dr
Y8XsgrwxVj0zkL8ixkHIs4ixBPkw5PeQO4N8O3BXQbcV5wP5QY518G9OhQe5
ISbEftn4PEvVy1lgcDIVP6ch/8Fpg/5NEAb9OfUWZ1Ur6zwK+wnYtyXihDyN
Qv8kVc+PcJ9JZENbzgVr6IVNA/4P59Qra2R84s3YVe6X3BBv4ky/CfvSZygn
mX55+z4I6qsZ970g3O4E8UA+Bs3JkHnhPWy52zGYaw9qXYLvXuPGGWswvsT5
AHpaXS59OeQviTisxv+WVDhxFjhftZ7PUkZ4luD/ORG3m2BTA/knbI6Zq0q/
kaFUc8J5+YF7LfRXI9U86N5Zc4/fXV1Os8T+iQlj/avDfBHPiVRz/zQVtlPG
d9zf38xj3lyTo0Ox8GGN37PKy/6Jw92g/N2e7Qnb9XonFFe4i8UZe+Y7oUyb
Jc8McxYcnz3OZfTG6M+55Hy+RI27gv7NQu6Avgj5VtDbpS1nbzhVnti757n5
3Qy7R7DbEpTnh3OR/wb3WOV3Q6w2QDef8XcsfMkx+170O+VeY45P+HcR+RYg
30D8fUFc8w0x/6jfHd80OWV9o0HzwzlqD3pX73DXpaptZ6J9V3JfrKPk2piD
uS4k4rDRPPZ5/3AGt+Nchvwxpz4W7F9w35fd+5DfIP8tOBd3DOeV+Ykx8aW+
6N3X717qvfe4r6lfSsRnq+0LifbXBfzvTIXp+VQ5Jz3Hg36bxId7h7P8OBVH
Bc9Sm3fIFfT3ItUMcBbGg+rrMPZF5632nh/xrmUc9ss+5jwr7JccEU/OBTni
DPBNdnmO3pjHuSCfiux/LubNzc0geTfu20G7dyDo3TAuY455Rn+jznPmmpyf
8Jvnnl5e4ZA4B+Ffh7s20e5pCZ4H5/0LW1IdBQ==
         "]], PolygonBox[CompressedData["
1:eJwlkz1I1lEUxs/r//X+r7MQKS412mIQuUiCCr0VNuTUqkEI8ZqvBSYqagq2
teZsg1YiLuInvjmUH4VSQzoITRUYguBnDf4ezvDAc+5zvu45915p7XiQLzGz
GyAL3qdmtYnZNYzhYNaJfY5DOWf1sqNZFdpCxuwp/JCzdvTPYBV7EFSj/0Sf
IPY6WER7xNkffG+jH5HrBDRij6Ffhk9S+w38V6nZXMZjarC3QDf8G9iGD4J9
9C4wAF+K3kue/MvwTbCFbxf4F7ymareBGbQn0WsXiXmBFtQDtXPUvVRm9gW9
H98KfHJo9dgj8FF8bik/NR9iPyP/BrwOfIIXiCmi51LvVT4HpT4zzU53eh68
hmppprP4NoM18zveh79Ovbc20IT/PXKeJT4jzUo1VVs9fkW7g/29xGc+EP2O
uusrcv4mfhf9ceIz0+x0J91NOe/i+zF679rhCnwj+i4L4BzffPTdaOcd8Lfk
2EbbI99L9AZwnPhOtduz4LHawTp2D3Zl1n1y2EPBY9XzOLl6QYKWBX3wndT5
D2qeMqdC6rNo1AzhZcF5E5iXb/C7akfT5P8ffPfqcQV9EtxEuwpagr9JvU2d
vUv9TJp6UC/KqdzaqXb7IfW3pj8xpbcc/a3pzfwldij6X9EOtcsL5M51bA==

         "]]}]}, 
     {RGBColor[0.6363636363636364, 
       NCache[
        Rational[3, 11], 0.2727272727272727], 0.6363636363636364], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFUz1PVFEQvbvv7b3P3qCWW1oJRjoawcgarfwqoNsEY4JR2LVhWVDhD+gv
MBp1V/0BfkWDaKKyLiQ0akH8AXZU6lp4jucYipeZN/fM3DNn5lbr185eLYcQ
LuPL8J2uhNDLQxgguFkKYQ62g/jTFMIoAI9hl4sQDgNzA/YD/reAuwM7j9h5
YLrAL8QQDuH/CjB9nE0jvgR/A98i4r+isO+R+wz4LjDH8N9Jup88WKeaKf4d
uBPI2Q//NjAXMuUzt5SJW6Ok84E5vwHuJP5fJ/XRqCi+A9wsvufwryf5d5Pq
sS77Jt+pTGc998X4GnA1+H+i6kzC34ZdyuWzZhOYGcRewfbL4sD7eV4zfigX
5lEQL57z/wFyRoBZQf1N60b92NsPfF+CtBhG/CP8M1Ec2UfVOjG+jXpHMnE8
bh7jsOVMerFODbNYx3kLNdYKzW8dtpWrd87maKa7yPkA4gdzaUj+5D1jDXas
J++lT3zJM+Fd56L8J+DQrahWx7OrupcJYOqsV4jvnHeQe0Q8z0bNn/hh98u7
Lnp23Ady2rK2Lfe8mJRP3oz/329yIB/2wjPWHHF9alN3He47e+N9zOVOMP9+
ks73YAdRe/C5EJcFY9q5NKWetNx/akWNW/bfIacJfzeKKzl/9U7yLr6Ftvfg
n5YV8SZ/zq3p+i+S+DVg3xbKG4O/GjXLh/BfJsX3ka9rsjZ1Z7/jUXp3rclP
2EvI/Zb0/jmDW8B+StJ9wzznzeFmIf1OJc+nvLc/Q57jZNSc+FaYM+XZUbO+
Z8PYtOPcO75t9jvrM+r2O0rfHu6cSMLugm+7EI7vY8z9su+/Q4Gnww==
         "]], PolygonBox[CompressedData["
1:eJwlkskuhFEQhevvbv//20uwtLQyhAcwRBM7CRs7CRti3Gi08QV4AvMQHgAx
DwvdpqQ3WIgHsLMxLnwntTjJqapTt26deyt6hjoGE2ZWBVKgMTTrCcwuQWts
1kFckTQLQCYyS4MCDZWIp6n3g1J4Ocig/QOtaNPgDO0JaIHf09MAv0Q/gnaH
WRfwGfSFwHvOqd+Sm6J+TW6S2iK5Empl5MaJ24hv6K0htwGfD51Xg3XiLfBG
bx3xDnwVVCX9zrr7C+gjfkczDd+OXKsdtesd87PMOmBGC7VnkKD2RPxZZLZL
PEpvPbm9yM/QWcpl4cWh79aOtrTYbJNcbdJ31K5HxL3wYe5zDM8yr5t6P7mp
2D2Td7rDL/oV4tfAd1iDf5AbS7mH5+iXI++VRtqZ2N9GHsgLeSbv9EZ6K3kq
b3XGFXEeTRdn73PnJvhA7G+pP9CEdi72XeX5bOwey2vttBD6DtpFb3wqb8Bv
wt+sOfQ/o78jDyfgjZH/hQwzvqh/FPlsefAQuefyfpJ6nnlLxI+Be5YOvUe9
nbpT5BDXDjn4d+i9EyAX+xvoLXSnw8hzqumP/aD9By3zZVA=
         "]]}]}, 
     {RGBColor[0.5909090909090909, 
       NCache[
        Rational[2, 11], 0.18181818181818182`], 0.5909090909090909], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFkztPVVEQhTfncM++CTRWNjZ2NNrYXcD4IhTSgIUNlQmNCQ87MD5+gz0J
aIHUGGiEi1DwMHihEAKXXyClDdcEE9eXWcRiZ/aes2ZmzZo5t19Mj00VKaXn
OqXOUVdKZzprurdySuNy/q6l1OxO6YfOrvwdBdwpA7sizIDux7LPZG/qrAqz
Jey2zo7ul4qfkP80R45+vf8qR1PvIfnXc9Q86I66m8ZQ86oI/0t9f1eP+sPC
t4rgdi7/ot53dV+QnciB7ZEd0TkR7qnsqyL4kn9S77buN2T3/K1TCVdFLDnI
23EMueEN50YteuM+Ldwf2RnZX8INCjcjO0dO2bEqeuAb/nlh75fxLuuB762i
1q0ytFq1nuiKftTiTdygY+/ZosWXHH7yoeVILTRbt7ZfZYermMuHHNo2rD89
0/sj+V+b81z+X4P3hjAPdF/LwYVY+LSL6OfCc6Mu2i7liH1fDx8c8JMDrejx
wlqQnzlvWk/wB575vufCfB573t9lD4uYKfuy7FpL7uubtaJOx7WeOGYohwbk
Zj/Re8v7ieUNB+bMvK/3nNmA+eQdY9fgDO56P9kZcraMP7ImcOQbvODHDjTc
LzzZDzT4bI5njkX/pv+10SriZoV5mEPLjRz/36H384207hP+bT1yN12L/4Qc
H3PoTV7q9bnfc/Nrm//PHHGj3ouW8/8DueqfkQ==
         "]], PolygonBox[CompressedData["
1:eJwlkjsvg3EUh0/7ak8TXVgsFiYLixVxjaFdsJokFkMvYRDX+Ah2ibCw0y5S
EQMhwYJQ38CEREJC4vk5wy95zv1/zvt2zZWnS2kz60YtaDNn1p+YXcIbcN7N
nlNmjyQV4VFUhevER+Bd1Ef+L74luBUtpKJGtRX0TWyYnEbWbAv1wl/4SsQ+
Mmaz2LfYY9jXHqwZV/Ai+oE7yJmktu7R64L5n5nooV6aUYbfePMZi1SYf++R
o9xzfO/E2vHtkNtEU/ADGkiiRrXrqAd+of7GQ+L/N3rsqF07sYvZ6Kne6lEj
NoHu0rGjdj2RL4kdtMsTmsd+pecqXPC4rWrGPXqqt96wlosc5VbRCtzwuL16
nsJtqJmKmxeoPcYeSmJH7brtcbsZfVN42eM2g9hHcD4brBrV7nl8e33TffjA
Y7b+iUP4DxggTiw=
         "]]}]}, 
     {RGBColor[0.5454545454545454, 
       NCache[
        Rational[1, 11], 0.09090909090909091], 0.5454545454545454], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVL1Om0EQPGP7u5MwlkhBDRRgY/PzBiFSUpEiUJMCE1pImcpSlAYeACh4
BDAuCOlimxBken7S0IcOU0RpM+MZKcXq9u7b252Z3fumGjtr2yMhhA+wPGyx
EMIGnN+5EOaKIXRhV0H+FmwZ59sxhAesn7MQvsPqSPARZ8e49wr3q9gfwjqI
r2D9im/3yFFC7NuobyWsPeyX4B8k5XjpuqzZcd1NnH1BzkecdxA/j7gxxPfw
vQabw34wotqsW8Z6AqvRT4p/F5WnAbtDzr84O4L9hF9Bjtmi7l5j7bt2Ky/O
xFBCnjb2+0mxvEteo0l1p6mB8VAf4ukbG7mR4wVizqJE/hRVt1oUTuIiP3Jf
tVYvoow+9SO+Wet5k6RJLgoLz8mFuKktMV9Y28tMvLrGU7L+o1ibxrxk3arW
gXgmrdWOe82eD/U2x+ekfv3B/sn9JrbTvOaE+g3xGhv1GDiGmJ/sbzlny/Ur
xjBImsM71J3JVHMiiWPfOlAv6lbL6ezaHImzbl7M++CYsbwwMObeM/EL63kU
l2fPVdeY2POsIE7UZKEgXRb8RiadmzWoedcYOuZaNccN3yFeYmsaZ8X9pz6s
v+gY4mwaPzUpe555t1f8/y57zlO3FuT4w1pRs/dJ+NeT6jf8vrhueuZ2o/Lv
Rb3dst/RbRTugWefGjA/15Z9vq22ffaR31ibM0E+35BjJVO/xz1v5EbM/HdQ
uzeeL3JgntdRWq5E6Rs8h4+uN+yj3zXf9z+SnIr3
         "]], PolygonBox[CompressedData["
1:eJwlkDEvw1EUxe+/r32v0pKIhElCGSv1DUrCVANmBoSNGrsb1AdoOpjMhISw
aYT0E9BafAAbU61+N2c4ybn3nHfvfWd+v7l9kjOzWZAHg2S2F8xqFPfwc7AK
v6ZXKppNUl/y4A8cwy/ARJDHvZtgCe07M2tHswUwjr5M7wXeYcZdkKdHPTVm
Vi2YreB/pW7wvs8dXfQN+A7+mNebMnyd3lcmzxr8EPzkdFMj6ma/vY7/Ef4W
tdt3+K5PegdoA96P6G2hzwX9+QOtBSyo59pT0qwqM56py2CI5Ype4J7TJM1v
asJn6N0G3bwLr0Rl94vnKCkTz+YM/R19kfomKMM2+nRRWfgMn5Ulef3mYdJO
3+03PiTN9NmesWddSsrOM/Fs/gFtMzX6
         "]]}]}, 
     {RGBColor[0.5, 0, 0.5], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFUrtOw0AQ3HPM3SHSIUENoQkNICGXkWwSakQNDUKUUEd2asIH8B9AmQIh
+IQgUH6EmhnNIorRnfcxOzvnnau789vCzI6BHhDWzApgGsxGQAUcAM9IPvUU
b4AONTXOcWk2w/0E500yGyK2G83uce+j/gHnKXIL3FvkltlshYHzqB7ykJ/f
jJ8l8bL206SFmlqfW3ucfY1re0fvEXo318HpmpcmvdR9GDSLceojH3Pk6Wft
dJG1R+e7NKV6p843ck7mZ7478y/OX/kM6qGWNvz7wzjn/qDvGvXfSfX0Z/jX
C+wDk1L9tfPQu9ZrK68hJ+tYQ8+6QhreovgGUT3ckzvSF3J9IL6RxcX3mSfx
7SF+mfVG21ngfSvLp+D/A99i4Z7Qg7FrYKzwNxq4Bv4L9Gbl2r6SdAacr1H+
PoL/F58ZPb8=
         "]], 
        PolygonBox[{{2140, 377, 954, 2141}, {2061, 945, 1090, 1726}, {2007, 
         868, 636, 2006}, {1570, 297, 780, 2059}, {1872, 729, 946, 2062}, {
         2197, 1090, 377, 2060}, {1731, 561, 1093, 1729}, {1729, 1093, 1092, 
         2198}, {2062, 946, 945, 2061}, {1793, 636, 729, 2259}, {2198, 1092, 
         297, 1728}, {2070, 954, 1094, 1574}, {1929, 780, 298, 1928}, {1574, 
         1094, 561, 1730}}]}]}}, {{}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1526, 2007, 2006, 1793, 2259, 1672, 1872, 2062, 2061, 1726, 
       2197, 2060, 2140, 2141, 2071, 2070, 1574, 1730, 2323, 1731, 1729, 2198,
        1728, 1571, 1894, 1570, 2059, 1927, 1929, 1928, 1572}]}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1873, 1810, 1972, 1548, 2051, 1971, 1912, 1617, 2004, 2288, 
       2005, 1970, 1973, 2289, 1525, 1974, 1725, 1904, 1903, 1902, 1665, 1861,
        1860, 1867, 1868, 1804, 1803, 1893, 1611, 1809, 1901}]}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1527, 2008, 1915, 1914, 1913, 1618, 1959, 1960, 1958, 2175, 
       2174, 1863, 1953, 1954, 1952, 1951, 1908, 1612, 2172, 2173, 1997, 1998,
        1522, 1859, 1994, 1993, 1992, 1784, 1858, 1857, 1981, 1982, 1980, 
       1979, 1907, 1607, 1937, 1991}]}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1528, 2009, 1918, 1917, 1916, 1619, 1962, 1963, 1961, 2177, 
       2176, 1865, 1956, 1666, 1955, 1667, 1957, 1663, 1984, 1788, 1983, 1787,
        2252, 1862, 2250, 1785, 2249, 1786, 2251, 1659, 2243, 1778, 2240, 
       2242, 2241, 1852, 1978, 1545, 2327, 1977, 1906, 1604, 1936, 1656, 2155,
        1657, 2156, 1603, 2119, 1602, 2120, 1658}]}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1508, 2110, 2111, 2028, 2224, 1540, 2225, 1839, 1768, 2226, 
       1769, 1841, 1840, 1511, 2284, 1653, 1599, 1905, 1975, 2326, 1542, 1976,
        1845, 1773, 2236, 2238, 2237, 1654, 2160, 2161, 2157, 2159, 2158, 
       1847, 2162, 1945, 1946, 2123, 2122, 1608, 2253, 2254, 1995, 1996, 1519,
        1864, 2001, 2000, 1999, 1791, 1870, 1869, 2178, 1668, 1964, 1966, 
       1965, 1620, 1919, 1920, 1921, 2010, 1529}]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzb1KgnEYhvFHwnTpIFrMxSVQWoLm0MXsBIJq0yWaakn0CFprKkHzI8jq
BGo2Ww0aWiShIZsCoV/DxXXf9/O+/Ff3auVqIiKKmCQj8umIAj5TEVe8tBxx
zRl9IrfkN87qa3j3z9RWtW1gZmvrHXRxg5ztw60nD9BHTX/gR9zhHkOs+/bI
bV8+xAG29G/7HCl56s2CPOMv97ntBE/yz7/dnrGJU/3VvuARj/GCbbdjvuBL
VOQdlHx3rjd4wE2+5V0+4zpW5F9v/wE3HzBo
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzsvQwEYh/HX4DL5BDRhUoOELiaJyyIRQ2eTpUTiEqFsBr4AYWn5HNQg
IdSsTdpBaWklOthMFr8zPHn6/N9zktOR1a3sZk9ErOCvN2KwL+KkP+IYFzhH
BS/IYx97WPbcwUDEIfI40mf2RV7Sp34XUcCunuEnLuMRv557Tt7labcH3ONH
39lneY4XMI81ZNxvuIRrdD1zyzs84dby/V3d0dto41s37Wn3Bn/pN/sGGujo
V/uoe50/dd2+jho+dM2ecq9yU1ftw3oIV7qiL7mIti2jc3hPbt4Z5yk9xpOc
Tv4P/wOq4jn1
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzkvhFEYhuFDMrYaESTWitFRGJFoSEhEYquQWBoKkonaH7CVMyhsBX+E
2GmnECIUwiBUluD6ijv3+zznPV/OVzMx1z+bE0JIYjA/hH4MIBfvBSH8xELo
M39wUZ4l3Z88zEN403/LX/hEj51e/bP+UF6Q5+Uu7uZOLisMIe1sRp5GqzmB
V2dZ+dHdZvmBY7oXcxbt5g7nd/onTsqJiOgb3MYTGEeD/X2+0e/xLdfr6pBx
/16X0bWg0dyEOMZQZWeLt7GJXexgyu4VSrz/MvoPe+dcKV/wJE5RLJ9wqfMj
rpCPeQzrvrOBNRxEu3bS5l9vSvG1HNfXmke43N3R6I2ojv6La/jM/ordVSxi
GUtI4R9kXT02
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0Dsvg3EYhvHHuWYRaU0GiYToYmudBkaHDorFoZiEQSyMBvFxfASJSEhE
OlhoXhGhSKQkWPm9w5Xrue/n+ad527e+W9ppiogKLtsicpmIXmQx0B5xjnvz
lV1XR8Q11+QL/Qq6davc0hmxxnkkugf8ub1Bj7nKiXdV+5ycxaa51bstHsGz
7gV13Lofdp/Hq/yGZjd3+n5zwnW7R92QPIiKvC2PcoGLXOQN3uMzN0/eTcpj
ckP+xFf6u/op/TS+5R9k3LzrC+YPbtj96ibkcezLs5jDDEqYxwEOsZju3ZfT
G17iYz5Nv993L5iXdWU+4pP0v7ar4R9O3DZ1
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz0krhXEYhvH/kekgltIxZsqCTDl8DVsynJUU1vbmeVpQlKKUpSTyEZSk
DBvlUDZKlJCQ31lcXc9zP/f7vr0ViZHO4UgIYRRnGSGUZIdQimLUZYZQxl1c
xfVcyQ2cwJ353DPV3Gi/zwohiWC+kNfIa/Ege0REfimPma856XYlq7CXo9fe
hObU+9CKFvRhUK+d2zjOce7gIb7hW0SRgzLZYOqdPMGZSIv6jn3A/MQH+NYt
5G7ZOufpbPAzDvHjXsQ97puc777FrzjCn3uM+9z7sW3+4E984cU/zugcy6f5
hGd5h8d4N/UNvV/84U1/Xn4qn+NFLGDPPs4TiCANubJ3/WXzCpawhlXsu03y
FNKRgQLZr/4/RgA+ZQ==
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0clKXEEYQOFqtCdFux1aRFRwIb6PoNEWEdqAhEh8DXGeBQVDAkqCMyKC
BFy6cSWJoMtssnEjDlHE4avF4dy/DrequLetNNL5JRFCGEVHKoTGTAgt2RAq
0iFcea5HAZ/N7Xqei5yxlkYKPeY+DtpPz7Xe/8Efza2cMP/iV2ygxrzOg3oL
B/Mx/8f3eIb5G5f0Zn6z9xHf4Cty+hoP6E38oh/yNVZRpa9wv97Iz/oB/8My
KvWleGe9gZ/0ff6LRVToC1zUC/yo7/EV5pHV57hXr4/31nf5ArPx2+gz3KPX
8YO+w+eYRlqf4g96Ld/r23yGSaT0Ce7Wa/hO3+JTjCOpj3GXnudbfZNP4tnW
xuK+1uowFPfgPHLxn5kvuTfel8vNv7mM/3CWc6jGMJL4hCq8A/2UP8M=
       "]]}, {}, {}}, {InsetBox[
      StyleBox["\<\"0 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {9.4, 0.51}], InsetBox[
      StyleBox["\<\"1 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {8.567916342700551, 0.99}], InsetBox[
      StyleBox["\<\"2 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {4.404845704708276, 0.51}], InsetBox[
      StyleBox["\<\"3 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {0.45, 0.5428416430362186}], InsetBox[
      StyleBox["\<\"4 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {2.63971772145512, 0.7072998282129582}], InsetBox[
      StyleBox["\<\"5 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {4.856331762744049, 0.99}], InsetBox[
      StyleBox["\<\"6 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {0.45, 0.8152073291755136}], InsetBox[
      StyleBox["\<\"7 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {2.881660592919575, 0.9553571428571426}], InsetBox[
      StyleBox["\<\"8 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {1.015806370664754, 0.9257903185332376}], InsetBox[
      StyleBox["\<\"9 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {2.1437998473365134`, 0.99}], InsetBox[
      StyleBox["\<\"10 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {0.45, 0.9792268994036885}]}}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"RMS Fluctuation angle, \[Theta] (\[Degree])\"", TraditionalForm], 
    FormBox[
    "\"Propogation Efficiency, \\!\\(\\*SubscriptBox[\\(\[Eta]\\), \
\\(prop\\)]\\)\"", TraditionalForm]},
  ImageSize->{557., Automatic},
  LabelStyle->Large,
  PlotRange->{{0, 10}, {0.5, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.455641452019916*^9, 3.455641459414316*^9}, {
  3.4556415288343163`*^9, 3.455641534309916*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"dB", "[", 
     RowBox[{"(", 
      RowBox[{"Sqzfluc", "/.", 
       RowBox[{"\[Eta]prop", "\[Rule]", 
        RowBox[{"0.815", " ", "0.75"}]}]}], ")"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Squeezing level as a function of \[Theta], for given propogation \
efficiency of 75%\>\"", ",", "Medium", ",", "Bold"}], "]"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<RMS fluctuation angle, \[Theta] (\[Degree])\>\"", ",", 
      "\"\<Squeezing relative to SNL\>\""}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "3.3", "}"}], ",", 
      RowBox[{"{", "3", "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.455643912625716*^9, 3.4556439720857162`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd1Hs01WkXB/DDiYpfJkxGynE5oSRJmlLYu4yUKe8UUiiRSwqVBoVkSG5d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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"RMS fluctuation angle, \[Theta] (\[Degree])\"", TraditionalForm], 
    FormBox["\"Squeezing relative to SNL\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  GridLines->{{3.3}, {3}},
  ImageSize->{741., Automatic},
  PlotLabel->FormBox[
    StyleBox[
    "\"Squeezing level as a function of \[Theta], for given propogation \
efficiency of 75%\"", Medium, Bold, StripOnInput -> False], TraditionalForm],
  PlotRange->{{0, 10}, {-0.13096060593784356`, 3.5834138979374663`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.455643914933216*^9, 3.455643972415716*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Assume ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "CD"], TraditionalForm]], "None"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "LO"], TraditionalForm]], "None"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "SB"], TraditionalForm]], "None"],
 " to be the light amplitude after the OMC for carrier contrast defecct, for \
carrier local oscillator due to arm offset and RF sideband power"
}], "Subsection",
 CellChangeTimes->{{3.455467114985044*^9, 3.455467147105044*^9}, 
   3.4554697268416443`*^9, {3.4562415614375*^9, 3.456241686484375*^9}, {
   3.4562423759375*^9, 3.45624238675*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ECR", "=", 
  RowBox[{"ECD", "+", " ", 
   RowBox[{"\[ImaginaryI]", " ", "ELO"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ESB", "=", 
  RowBox[{
   RowBox[{"ESBP", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "-", 
   RowBox[{"ESBM", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", 
      "t"}]]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ETOT", "=", 
  RowBox[{"ECR", "+", "ESB"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComplexExpand", "[", 
   RowBox[{
    RowBox[{"ETOT", "\[Conjugate]"}], " ", "ETOT"}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ESBM", "\[Rule]", 
     RowBox[{"ESBAVRG", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Epsilon]"}], ")"}]}]}], ",", 
    RowBox[{"ESBP", "\[Rule]", 
     RowBox[{"ESBAVRG", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[Epsilon]"}], ")"}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[CapitalDelta]PSB", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["ESBP", "2"], "-", 
      SuperscriptBox["ESBM", "2"]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ESBM", "\[Rule]", 
        RowBox[{"ESBAVRG", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Epsilon]"}], ")"}]}]}], ",", 
       RowBox[{"ESBP", "\[Rule]", 
        RowBox[{"ESBAVRG", 
         RowBox[{"(", 
          RowBox[{"1", "+", "\[Epsilon]"}], ")"}]}]}]}], "}"}]}], "/.", 
    RowBox[{"ESBAVRG", "\[Rule]", 
     SqrtBox[
      FractionBox["PSB", "2"]]}]}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}]}], "Input",
 CellChangeTimes->{{3.456241702875*^9, 3.45624201015625*^9}, {
  3.456242052484375*^9, 3.456242054484375*^9}, {3.45624219803125*^9, 
  3.45624220928125*^9}, {3.456242241125*^9, 3.456242324140625*^9}, {
  3.456313853375*^9, 3.456313857265625*^9}, {3.45631548753125*^9, 
  3.456315521453125*^9}, {3.45631581378125*^9, 3.456315816609375*^9}, {
  3.4563158815625*^9, 3.456315882046875*^9}, {3.5320539786826906`*^9, 
  3.5320541268931675`*^9}, {3.532054470501821*^9, 3.532054510475107*^9}, {
  3.532055184362652*^9, 3.5320552320763807`*^9}, {3.5320554432574596`*^9, 
  3.532055445761603*^9}}],

Cell[BoxData[
 RowBox[{"ECD", "+", 
  RowBox[{"\[ImaginaryI]", " ", "ELO"}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.45632658984375*^9, {
   3.5320540511048326`*^9, 3.5320541273581944`*^9}, 3.53205447921832*^9, 
   3.5320545114871655`*^9, {3.5320552021066666`*^9, 3.532055233486461*^9}, 
   3.5320554466536536`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]]}], " ", 
   "ESBM"}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]], " ", 
   "ESBP"}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.45632658984375*^9, {
   3.5320540511048326`*^9, 3.5320541273581944`*^9}, 3.53205447921832*^9, 
   3.5320545114871655`*^9, {3.5320552021066666`*^9, 3.532055233486461*^9}, 
   3.5320554466996565`*^9}],

Cell[BoxData[
 RowBox[{"ECD", "+", 
  RowBox[{"\[ImaginaryI]", " ", "ELO"}], "-", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], " ", 
   "ESBM"}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]], " ", 
   "ESBP"}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.45632658984375*^9, {
   3.5320540511048326`*^9, 3.5320541273581944`*^9}, 3.53205447921832*^9, 
   3.5320545114871655`*^9, {3.5320552021066666`*^9, 3.532055233486461*^9}, 
   3.5320554467026567`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ECD", "2"], "+", 
  SuperscriptBox["ELO", "2"], "+", 
  SuperscriptBox["ESBM", "2"], "+", 
  SuperscriptBox["ESBP", "2"], "-", 
  RowBox[{"2", " ", "ECD", " ", 
   RowBox[{"(", 
    RowBox[{"ESBM", "-", "ESBP"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "-", 
  RowBox[{"2", " ", "ESBM", " ", "ESBP", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "t", " ", "\[Omega]"}], "]"}]}], "+", 
  RowBox[{"2", " ", "ELO", " ", "ESBM", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
  RowBox[{"2", " ", "ELO", " ", "ESBP", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.45632658984375*^9, {
   3.5320540511048326`*^9, 3.5320541273581944`*^9}, 3.53205447921832*^9, 
   3.5320545114871655`*^9, {3.5320552021066666`*^9, 3.532055233486461*^9}, 
   3.532055446748659*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ECD", "2"], "+", 
  SuperscriptBox["ELO", "2"], "+", 
  RowBox[{
   SuperscriptBox["ESBAVRG", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Epsilon]"}], ")"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["ESBAVRG", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Epsilon]"}], ")"}], "2"]}], "-", 
  RowBox[{"2", " ", "ECD", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ESBAVRG", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Epsilon]"}], ")"}]}], "-", 
     RowBox[{"ESBAVRG", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[Epsilon]"}], ")"}]}]}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["ESBAVRG", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "\[Epsilon]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[Epsilon]"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "t", " ", "\[Omega]"}], "]"}]}], "+", 
  RowBox[{"2", " ", "ELO", " ", "ESBAVRG", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "\[Epsilon]"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
  RowBox[{"2", " ", "ELO", " ", "ESBAVRG", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[Epsilon]"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.45632658984375*^9, {
   3.5320540511048326`*^9, 3.5320541273581944`*^9}, 3.53205447921832*^9, 
   3.5320545114871655`*^9, {3.5320552021066666`*^9, 3.532055233486461*^9}, 
   3.5320554467526593`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", "PSB", " ", "\[Epsilon]"}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.45632658984375*^9, {
   3.5320540511048326`*^9, 3.5320541273581944`*^9}, 3.53205447921832*^9, 
   3.5320545114871655`*^9, {3.5320552021066666`*^9, 3.532055233486461*^9}, 
   3.5320554467966623`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.45632658984375*^9, {
   3.5320540511048326`*^9, 3.5320541273581944`*^9}, 3.53205447921832*^9, 
   3.5320545114871655`*^9, {3.5320552021066666`*^9, 3.532055233486461*^9}, 
   3.532055446798662*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EAVRG", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"ETOT", 
     FractionBox["\[Omega]", 
      RowBox[{"2", "\[Pi]"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], "\[Omega]"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComplexExpand", "[", 
    FractionBox[
     RowBox[{"Re", "[", 
      RowBox[{
       RowBox[{"ETOT", "\[Conjugate]"}], 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "EAVRG"}], ")"}]}], "]"}], 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"EAVRG", "\[Conjugate]"}], "EAVRG"}], "]"}]], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ESBM", "\[Rule]", 
      RowBox[{"ESBAVRG", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Epsilon]"}], ")"}]}]}], ",", 
     RowBox[{"ESBP", "\[Rule]", 
      RowBox[{"ESBAVRG", 
       RowBox[{"(", 
        RowBox[{"1", "+", "\[Epsilon]"}], ")"}]}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"\[CapitalGamma]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"%", "//.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ECD", "\[Rule]", 
            SqrtBox["PCD"]}], ",", 
           RowBox[{"ELO", "\[Rule]", 
            SqrtBox[
             RowBox[{"PCR", "-", 
              SuperscriptBox["ECD", "2"]}]]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{"PCD", "\[Rule]", 
          RowBox[{
           FractionBox["1", "\[Eta]"], " ", "PCR"}]}], "}"}]}], "/.", 
       RowBox[{"ESBAVRG", "\[Rule]", 
        SqrtBox[
         FractionBox["PSB", "2"]]}]}], "//", "FullSimplify"}], "//", 
     "PowerExpand"}], "//", "Together"}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[CapitalGamma]RMSSQR", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     FractionBox["\[Omega]", 
      RowBox[{"2", "\[Pi]"}]], 
     SuperscriptBox["\[CapitalGamma]", "2"]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], "\[Omega]"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox[
   SqrtBox["\[CapitalGamma]RMSSQR"], "Degree"], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"PSB", "\[Rule]", 
     RowBox[{"0.009", " ", "20*^-3"}]}], ",", 
    RowBox[{"PCR", "\[Rule]", "10*^-3"}], ",", 
    RowBox[{"\[Eta]", "\[Rule]", 
     FractionBox["10", "0.4"]}], ",", 
    RowBox[{"\[Epsilon]", "\[Rule]", "0.05"}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.456313825921875*^9, 3.456313828125*^9}, {
   3.45631385925*^9, 3.456313877375*^9}, {3.456313911078125*^9, 
   3.456314087234375*^9}, {3.456314148546875*^9, 3.456314266375*^9}, {
   3.456314362484375*^9, 3.4563143704375*^9}, {3.45631445775*^9, 
   3.456314480421875*^9}, {3.456314535234375*^9, 3.456314550859375*^9}, 
   3.456314734328125*^9, {3.4563148093125*^9, 3.45631482684375*^9}, {
   3.45631486190625*^9, 3.456314896578125*^9}, {3.456314937828125*^9, 
   3.45631493971875*^9}, {3.45631507803125*^9, 3.45631512175*^9}, {
   3.456315195375*^9, 3.45631527240625*^9}, {3.456315317265625*^9, 
   3.456315330953125*^9}, {3.456315552140625*^9, 3.456315679390625*^9}, {
   3.456326571890625*^9, 3.4563266011875*^9}, {3.456328016203125*^9, 
   3.456328097546875*^9}, 3.532054046961596*^9, 3.5320541572309027`*^9, 
   3.5320542333982596`*^9, 3.532054343961583*^9, {3.5320544118204646`*^9, 
   3.5320544123424945`*^9}, {3.5320544884888496`*^9, 3.532054532792384*^9}, {
   3.532054714988805*^9, 3.532054786779911*^9}, {3.5320549478191223`*^9, 
   3.5320549498852406`*^9}, {3.5320549811650295`*^9, 3.5320550060784545`*^9}, 
   3.5320550545822287`*^9, {3.532055086567058*^9, 3.5320551213980503`*^9}, 
   3.532055302053383*^9, {3.532055336833372*^9, 3.532055390625449*^9}}],

Cell[BoxData[
 RowBox[{"ECD", "+", 
  RowBox[{"\[ImaginaryI]", " ", "ELO"}]}]], "Output",
 CellChangeTimes->{
  3.456313878546875*^9, 3.456313916171875*^9, {3.45631395540625*^9, 
   3.456314008265625*^9}, {3.45631405115625*^9, 3.456314057015625*^9}, 
   3.4563140878125*^9, 3.456314150078125*^9, 3.456314267453125*^9, 
   3.45631437228125*^9, 3.4563144596875*^9, 3.4563148390625*^9, {
   3.456314872390625*^9, 3.456314897484375*^9}, 3.456314940453125*^9, {
   3.456315079359375*^9, 3.4563151225*^9}, {3.456315236734375*^9, 
   3.456315273015625*^9}, {3.45631532103125*^9, 3.456315331640625*^9}, {
   3.456315509921875*^9, 3.4563156806875*^9}, 3.456315931046875*^9, 
   3.456316197171875*^9, {3.45632657421875*^9, 3.4563266248125*^9}, 
   3.45632805990625*^9, 3.4563280981875*^9, {3.5320541400719213`*^9, 
   3.5320541645603223`*^9}, 3.5320542345263243`*^9, 3.532054312339775*^9, 
   3.5320543463397193`*^9, 3.5320544129535294`*^9, {3.5320544911280007`*^9, 
   3.5320545337324376`*^9}, 3.5320547229362593`*^9, 3.53205476822785*^9, 
   3.5320549507462893`*^9, {3.532054988029422*^9, 3.5320550074095306`*^9}, 
   3.5320550558823028`*^9, {3.5320550879821386`*^9, 3.5320551220650883`*^9}, 
   3.532055302576413*^9, {3.532055338677478*^9, 3.5320553926205635`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "ESBAVRG", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "ELO"}], " ", "\[Epsilon]", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
     RowBox[{"ECD", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], 
  RowBox[{
   SuperscriptBox["ECD", "2"], "+", 
   SuperscriptBox["ELO", "2"]}]]], "Output",
 CellChangeTimes->{
  3.456313878546875*^9, 3.456313916171875*^9, {3.45631395540625*^9, 
   3.456314008265625*^9}, {3.45631405115625*^9, 3.456314057015625*^9}, 
   3.4563140878125*^9, 3.456314150078125*^9, 3.456314267453125*^9, 
   3.45631437228125*^9, 3.4563144596875*^9, 3.4563148390625*^9, {
   3.456314872390625*^9, 3.456314897484375*^9}, 3.456314940453125*^9, {
   3.456315079359375*^9, 3.4563151225*^9}, {3.456315236734375*^9, 
   3.456315273015625*^9}, {3.45631532103125*^9, 3.456315331640625*^9}, {
   3.456315509921875*^9, 3.4563156806875*^9}, 3.456315931046875*^9, 
   3.456316197171875*^9, {3.45632657421875*^9, 3.4563266248125*^9}, 
   3.45632805990625*^9, 3.4563280981875*^9, {3.5320541400719213`*^9, 
   3.5320541645603223`*^9}, 3.5320542345263243`*^9, 3.532054312339775*^9, 
   3.5320543463397193`*^9, 3.5320544129535294`*^9, {3.5320544911280007`*^9, 
   3.5320545337324376`*^9}, 3.5320547229362593`*^9, 3.53205476822785*^9, 
   3.5320549507462893`*^9, {3.532054988029422*^9, 3.5320550074095306`*^9}, 
   3.5320550558823028`*^9, {3.5320550879821386`*^9, 3.5320551220650883`*^9}, 
   3.532055302576413*^9, {3.532055338677478*^9, 3.532055392669566*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["PSB"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Epsilon]"}], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Eta]"}]], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", " ", "\[Omega]"}], "]"}]}], ")"}]}], 
  RowBox[{
   SqrtBox["PCR"], " ", 
   SqrtBox["\[Eta]"]}]]], "Output",
 CellChangeTimes->{
  3.456313878546875*^9, 3.456313916171875*^9, {3.45631395540625*^9, 
   3.456314008265625*^9}, {3.45631405115625*^9, 3.456314057015625*^9}, 
   3.4563140878125*^9, 3.456314150078125*^9, 3.456314267453125*^9, 
   3.45631437228125*^9, 3.4563144596875*^9, 3.4563148390625*^9, {
   3.456314872390625*^9, 3.456314897484375*^9}, 3.456314940453125*^9, {
   3.456315079359375*^9, 3.4563151225*^9}, {3.456315236734375*^9, 
   3.456315273015625*^9}, {3.45631532103125*^9, 3.456315331640625*^9}, {
   3.456315509921875*^9, 3.4563156806875*^9}, 3.456315931046875*^9, 
   3.456316197171875*^9, {3.45632657421875*^9, 3.4563266248125*^9}, 
   3.45632805990625*^9, 3.4563280981875*^9, {3.5320541400719213`*^9, 
   3.5320541645603223`*^9}, 3.5320542345263243`*^9, 3.532054312339775*^9, 
   3.5320543463397193`*^9, 3.5320544129535294`*^9, {3.5320544911280007`*^9, 
   3.5320545337324376`*^9}, 3.5320547229362593`*^9, 3.53205476822785*^9, 
   3.5320549507462893`*^9, {3.532054988029422*^9, 3.5320550074095306`*^9}, 
   3.5320550558823028`*^9, {3.5320550879821386`*^9, 3.5320551220650883`*^9}, 
   3.532055302576413*^9, {3.532055338677478*^9, 3.5320553927145686`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"PSB", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SuperscriptBox["\[Epsilon]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
  RowBox[{"PCR", " ", "\[Eta]"}]]], "Output",
 CellChangeTimes->{
  3.456313878546875*^9, 3.456313916171875*^9, {3.45631395540625*^9, 
   3.456314008265625*^9}, {3.45631405115625*^9, 3.456314057015625*^9}, 
   3.4563140878125*^9, 3.456314150078125*^9, 3.456314267453125*^9, 
   3.45631437228125*^9, 3.4563144596875*^9, 3.4563148390625*^9, {
   3.456314872390625*^9, 3.456314897484375*^9}, 3.456314940453125*^9, {
   3.456315079359375*^9, 3.4563151225*^9}, {3.456315236734375*^9, 
   3.456315273015625*^9}, {3.45631532103125*^9, 3.456315331640625*^9}, {
   3.456315509921875*^9, 3.4563156806875*^9}, 3.456315931046875*^9, 
   3.456316197171875*^9, {3.45632657421875*^9, 3.4563266248125*^9}, 
   3.45632805990625*^9, 3.4563280981875*^9, {3.5320541400719213`*^9, 
   3.5320541645603223`*^9}, 3.5320542345263243`*^9, 3.532054312339775*^9, 
   3.5320543463397193`*^9, 3.5320544129535294`*^9, {3.5320544911280007`*^9, 
   3.5320545337324376`*^9}, 3.5320547229362593`*^9, 3.53205476822785*^9, 
   3.5320549507462893`*^9, {3.532054988029422*^9, 3.5320550074095306`*^9}, 
   3.5320550558823028`*^9, {3.5320550879821386`*^9, 3.5320551220650883`*^9}, 
   3.532055302576413*^9, {3.532055338677478*^9, 3.532055392936581*^9}}],

Cell[BoxData["1.5828574813699945`"], "Output",
 CellChangeTimes->{
  3.456313878546875*^9, 3.456313916171875*^9, {3.45631395540625*^9, 
   3.456314008265625*^9}, {3.45631405115625*^9, 3.456314057015625*^9}, 
   3.4563140878125*^9, 3.456314150078125*^9, 3.456314267453125*^9, 
   3.45631437228125*^9, 3.4563144596875*^9, 3.4563148390625*^9, {
   3.456314872390625*^9, 3.456314897484375*^9}, 3.456314940453125*^9, {
   3.456315079359375*^9, 3.4563151225*^9}, {3.456315236734375*^9, 
   3.456315273015625*^9}, {3.45631532103125*^9, 3.456315331640625*^9}, {
   3.456315509921875*^9, 3.4563156806875*^9}, 3.456315931046875*^9, 
   3.456316197171875*^9, {3.45632657421875*^9, 3.4563266248125*^9}, 
   3.45632805990625*^9, 3.4563280981875*^9, {3.5320541400719213`*^9, 
   3.5320541645603223`*^9}, 3.5320542345263243`*^9, 3.532054312339775*^9, 
   3.5320543463397193`*^9, 3.5320544129535294`*^9, {3.5320544911280007`*^9, 
   3.5320545337324376`*^9}, 3.5320547229362593`*^9, 3.53205476822785*^9, 
   3.5320549507462893`*^9, {3.532054988029422*^9, 3.5320550074095306`*^9}, 
   3.5320550558823028`*^9, {3.5320550879821386`*^9, 3.5320551220650883`*^9}, 
   3.532055302576413*^9, {3.532055338677478*^9, 3.5320553929415817`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       SqrtBox["\[CapitalGamma]RMSSQR"], "Degree"], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PSB", "\[Rule]", 
         RowBox[{"0.009", " ", "20*^-3"}]}], ",", 
        RowBox[{"PCR", "\[Rule]", "10*^-3"}], ",", 
        RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "}"}]}], ",", 
     RowBox[{
      FractionBox[
       SqrtBox["\[CapitalGamma]RMSSQR"], "Degree"], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PSB", "\[Rule]", 
         RowBox[{"0.009", " ", "20*^-3"}]}], ",", 
        RowBox[{"PCR", "\[Rule]", "10*^-3"}], ",", 
        RowBox[{"\[Epsilon]", "\[Rule]", "0.2"}]}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Eta]", ",", "1", ",", "100"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "8"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0.5", ",", "0.2"}], "]"}]}], "}"}]}], "}"}]}], 
   ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(P\), \(CR\)], SubscriptBox[\(P\), \
\(CD\)]]\)\>\"", ",", "\"\<Phase Noise (\[Degree])\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.456244786640625*^9, 3.456244848234375*^9}, {
   3.456244891703125*^9, 3.456244915078125*^9}, {3.4562449579375*^9, 
   3.45624497590625*^9}, {3.456245015015625*^9, 3.4562450191875*^9}, {
   3.45624538475*^9, 3.456245443296875*^9}, {3.456245493671875*^9, 
   3.456245594421875*^9}, {3.4562456449375*^9, 3.456245653125*^9}, {
   3.4562456891875*^9, 3.45624570771875*^9}, {3.45624578090625*^9, 
   3.456245835515625*^9}, {3.456247576546875*^9, 3.4562476261875*^9}, {
   3.456247855109375*^9, 3.456247868203125*^9}, {3.456248579234375*^9, 
   3.4562485825625*^9}, {3.4562499116875*^9, 3.45624991196875*^9}, 
   3.456252922234375*^9, {3.456255856046875*^9, 3.456255887640625*^9}, {
   3.456313708375*^9, 3.456313717125*^9}, {3.4563153668125*^9, 
   3.456315378953125*^9}, 3.4563157056875*^9, {3.456315953890625*^9, 
   3.45631595646875*^9}, {3.456316230859375*^9, 3.456316285359375*^9}, {
   3.456326384078125*^9, 3.456326384921875*^9}, {3.45632799071875*^9, 
   3.4563280016875*^9}, {3.53205556967669*^9, 3.53205557806717*^9}, {
   3.5320556859103384`*^9, 3.532055702951313*^9}, {3.532055784131956*^9, 
   3.5320557985967836`*^9}, {3.532055850399747*^9, 3.5320558510737853`*^9}, {
   3.5320559079880404`*^9, 3.5320559172915726`*^9}, {3.5320591946450267`*^9, 
   3.5320592104649315`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVjnk01AkcwMcY1ziGH7lNa83Ms1rpcEzC99sxxCpJWhIGobBrN2/zKscu
Uq5ny1EkK0IKLY2zpLyya00tL6Olx0jX7xfJfWTWbPvH533e57+PeWjsgXA6
jUbb+5n/XVVS/Gu84ymX+w+LzdM72WhlH14fyfkWhprzLiy1sXFB7+Q2O04k
5KVX0KNEbDyctrZmwokHnzd733nXsFHzXlcIi3MOuF3tTdZ5bHz7nKOrxrkE
/JRTLusi2fjsjWRCiVMNg/KjHeUsNvbEbPRjcFpArVt6ui7MDHtvBxz/yuxP
KLmemfR+1QSHfrjJ76L6waXDYzDzrjGO/xjmda76Obgb2pQG5hph/WyJj/Tl
CHQVgeiqnyGORl4uJf95Cf3OnrlTuwzQtfBL5gb5a2gu7+V85Opj2zIT2vRJ
0Ns9tD7NeB16ZpRF6K28h/pu+5G4r/Xwof8io81oClYDfk/l2uuiVa3MoyBl
GvYnqJP9hwk8LbBenpuegdCxXoN9OTp4d61DGJ80BzlOgtxTrdqo4VW5M2Rm
Hpw306tXFli4r3NSGpu6CLNWv1DG32thgfurEI7WMuifTLtdI9fAyahNgZC0
ApbXyg/Gt6mjbe2IbrLmKrTvOds3HMnE7LSXu7gpMtChV8qdt6uhJEFgM71u
DSoXXfTyGapokesnF5bLYevf7umm48q4wzSEY5pJw8rS631pUiUkad284gMK
qN4exlUdYKDB5sHwXk06XjrYNiF5o4juU86XvB7TsSI+Y0+VsiLG3fXlRWQr
YvRNU9bF9XTkDhjO2rgyMMv+ydozbwXsk2WZZLOUsLAvoMw8kYaJjYcctkuU
cEJhhJEUI4fGO+LcqznKKFY1kRxlrsHYo1nBRV8VvDwW4Ca7IoNC80d8R21V
ZI1m2rb6roKX+gczuz9U8fonzdZ/LT4BTalb2JWjhnEarzccercM2zw8xuhu
THQbV/SKfrIEUb8ldUhY6shXWEwbrVkECwx6HtCrjukB4v1OVQsg/a7glW2q
BvYkrA9caZyH/FsJe8s8NDH1uDjEqmUO+m1Z8/cZWphl4+C0MDgLyk+9l2Of
auFx84gV/scZcJmfmIrLZ2HisnNnlv4MyBsNLxTwtFFyOr+iyncaXsTl+bdn
auPmkZNbNpl+hDPDYQ/45Od+O5Hc0/oBSlSEZWO7dHDax/7B4+hJaHeyve1d
rYNb8yqWpogJKDEIOmLKILA29v0hSkqBsWNXQ7sSgYpSSXfdMAVFR3gq/ioE
ir64IYiTUFB4baqhgEngZTovVqGXgtwNySosHQK9adnRVs0UpEBZowKbwDr2
N8P12RRERo6rvnMgMLXaUu9nRwreZrgGnd1GoCy7dCncjoKjtTfvWGwn8F6c
wyvPTRQIZ04ECV0INKqU9ZvxKDh8RlE0tJtAbr5cRaxDgWcuJ1jsTSA1Glrt
T5HwV8N5UZQPgYHH9Oe9XpPgPjCppuZLYKXPFYGblARXoyaRwI/AuSDXRb6E
BKgQMDuDCBxQCT5v+ZCE+49rggOFBGbqvVjg3SPBidRsWg0hMLQ5NYLXQgLf
ejCYH07gimnGfss6Epq9HJsGIz7/Wyf2WN0gwe5EKfOnYwQWx4h3b6wgQZRP
F+pGERhTtLNrSykJW1oimhqiCSxJvrWDX0TCf8hPLoU=
     "]]}, 
   {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwVkn040wkcwGc2wzB+Iy+xJyw9uFQXeal8vx3TUVrq1PIyo2alepCXdNV0
XnKJlIxoISWXlPOWJ70sSldxpJKL6yQORSpS6jfbdX98ns+/nz8+1hHRG8RU
CoXi/43/fUFedHyvxz5P19lcm8MKDjosE1+RcDfDYdsM6eImDk4bJ7q7cCVA
3eHQ11fPwaA0lWoudy80mrTJXCo5qH+jJZzFzYB2m+PM6TwODvdw2TrcAjBL
tXp8LoqDT/7tHqNzK4C19lSeYg4HH+xyEtC4jcC9H/zTcKwVtlUH77C3ug+D
dfY5x8wt8XlMpVvL6y5gHhr67fSIBb6K3crPqOgB2O3VW/LAHK9Myjf2D7yA
yrCOr0FlZviP5FTx6F8D4E/1cnCXm6JPvo2uo3oI6pLAyfbYHLw2owvX5ozC
mdP9PSm5Jrj2SGmk8Zc3YL21ODKozhibt3yiXTOfgKX8jLFdf7LRoUrpJ0t5
D1YJ6wflGmz8mbdwZur9BygsC7U74kXgddVN0V7pFCRN7TlwPdkI9fjlP4R/
+Ag7EixU2x8b4jrFeH906ifoXLUuNWCeIcp8B8O5BjPguNlU+nraAMejFoeC
9At0fLfi8sUufXSuesFO1ichaMTXs6BcD7PSBrzmpyhBZr3M8qqcid0HeIve
m6iAx2BFZWbrom2OQC0qUwP7spPz+VwdXGUZzrXMpGBnPOd1VYM2jlLu2RVt
0MBsvbOdLU8YaLrkmbhNn4rCsaeRFvoM9J1YWcBvpWJq/Jn9gkAtjLseaBeZ
pYk9zKKCu4V0nP/UbHKRDw1LFttLV0/T8JHy6NwsFh0/P3IM/epPw4O1m1yX
d9Oxep6plF+vibV17TlnsrWw9n5/65eFmvjy7iQvN5CB4uDex6XlVMy3vuvm
YaiNAU032NVOVOQz31q5/KGNrNm8oUPNGkih3xO1ZOtgu/Eixdi3bnc/v5fU
1bp4YSDm3Z1JCkaVSG92s5io1gpwuHOCgrYo7AluY+JXZ5PaopUU7N8tG3RO
1UPvKauQ7AE15F064F/qp4/Hk4LlL3zU0OXM+niLZoAPX42UmjSrQKsjYCa6
wwCVifFp7zxU4PlxbCIuj4Wx4ZlpB5tnQV1rdkJmZ4hv9JzErYJZ6Is7uaUp
0xAbvRnDU++UsL936223UUNMLLS5opApQc4Qlb70MkK8en4p1VsJTSucqwMq
jPBvIb3Yf5IEuakwxJJGoNbQ0d4FVSRYeLTUNNEJdPg8sImsJKEwxI6xhUHg
6hEVdF4kIf/sRI1Ml8CyBRRBUgUJOY7JDJYRgYIi3unOMhJSoLRWg0Ng2hR3
fW4hCRLJK+0RVwKpD9YkSzJIGD7iI0x3J7A54tb6Hw+TsK2qss52OYGjtJJM
+3QSRB/2CEWeBDIKrF3fpnz7br9m/XNvAtn8mOh9UhLW5nDD2gMIPHkzDsoT
SHhY82t91EYCzV26MrLiSfB9Oq6jE0ig1y8Hl8XHkeBj3lDPExCoVi6/5x1L
Apzj6SqEBKYvOX/pzS4SbrVeDAsVERhxu82meycJK0b1G8hwAju6XNSKKBLc
Fj4LcxMTOD6zZiR/OwlX+R4NzyIJ/D2iYTJFQoLLnmLdhO0E2n7ui4iOJKE+
jypiRxFokFjsGiIm4fvGyIaanQROVvTF+G4j4T99ACia
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{9.398306502016513*^-8, 0},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[SubscriptBox[\\(P\\), \\(CR\\)], \
SubscriptBox[\\(P\\), \\(CD\\)]]\\)\"", TraditionalForm], 
    FormBox["\"Phase Noise (\[Degree])\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{0., 
       FormBox["1", TraditionalForm]}, {0.6931471805599453, 
       FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {2.995732273553991, 
       FormBox["20", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {5.298317366548036, 
       FormBox["200", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{{0., 0.6931471805599453, 1.6094379124341003`, 2.302585092994046,
     2.995732273553991, 3.912023005428146, 4.605170185988092, 
    5.298317366548036, 6.214608098422191, 1.0986122886681098`, 
    1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
    2.0794415416798357`, 2.1972245773362196`, 3.4011973816621555`, 
    3.6888794541139363`, 4.0943445622221, 4.248495242049359, 
    4.382026634673881, 4.499809670330265, 5.703782474656201, 
    5.991464547107982}, Automatic},
  Method->{},
  PlotRange->{{9.398306502016513*^-8, 4.605170092005027}, {0, 8}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{0., 
      FormBox["1", TraditionalForm]}, {0.6931471805599453, 
      FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {2.995732273553991, 
      FormBox["20", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {5.298317366548036, 
      FormBox["200", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.532055703793361*^9, {3.5320557846639867`*^9, 3.5320557999048586`*^9}, 
   3.5320558516238165`*^9, {3.532055908864091*^9, 3.5320559180096135`*^9}, {
   3.5320591985492496`*^9, 3.532059210756948*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{953, 1056},
WindowMargins->{{Automatic, 126}, {-3, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 222, 3, 103, "Title"],
Cell[792, 27, 222, 6, 35, "Input"],
Cell[1017, 35, 1066, 29, 102, "Input"],
Cell[CellGroupData[{
Cell[2108, 68, 129, 1, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[2262, 73, 235, 5, 69, "Subsection"],
Cell[CellGroupData[{
Cell[2522, 82, 9899, 250, 989, "Input"],
Cell[12424, 334, 64050, 1122, 757, "Output"],
Cell[76477, 1458, 5145, 90, 375, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81659, 1553, 56, 1, 35, "Input"],
Cell[81718, 1556, 77, 1, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81832, 1562, 422, 9, 58, "Input"],
Cell[82257, 1573, 230, 4, 35, "Output"],
Cell[82490, 1579, 214, 3, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82741, 1587, 452, 10, 58, "Input"],
Cell[83196, 1599, 206, 3, 35, "Output"],
Cell[83405, 1604, 190, 2, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83632, 1611, 140, 1, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[83797, 1616, 375, 8, 58, "Input"],
Cell[84175, 1626, 231, 4, 35, "Output"],
Cell[84409, 1632, 213, 3, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[84671, 1641, 167, 3, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[84863, 1648, 511, 14, 58, "Input"],
Cell[85377, 1664, 158, 3, 35, "Output"],
Cell[85538, 1669, 142, 2, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85717, 1676, 4046, 110, 366, "Input"],
Cell[89766, 1788, 63602, 1107, 709, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[153405, 2900, 976, 26, 146, "Input"],
Cell[154384, 2928, 4127, 76, 498, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[158572, 3011, 635, 18, 69, "Subsection"],
Cell[CellGroupData[{
Cell[159232, 3033, 2397, 64, 225, "Input"],
Cell[161632, 3099, 765, 13, 35, "Output"],
Cell[162400, 3114, 1015, 22, 35, "Output"],
Cell[163418, 3138, 1052, 22, 35, "Output"],
Cell[164473, 3162, 1397, 30, 58, "Output"],
Cell[165873, 3194, 2102, 53, 80, "Output"],
Cell[167978, 3249, 747, 12, 35, "Output"],
Cell[168728, 3263, 702, 11, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169467, 3279, 3890, 100, 337, "Input"],
Cell[173360, 3381, 1258, 19, 35, "Output"],
Cell[174621, 3402, 1615, 31, 54, "Output"],
Cell[176239, 3435, 1659, 35, 66, "Output"],
Cell[177901, 3472, 1466, 27, 59, "Output"],
Cell[179370, 3501, 1215, 17, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180622, 3523, 3458, 78, 244, "Input"],
Cell[184083, 3603, 11261, 208, 364, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
